@@ -1,6 +1,6 @@
 /*
  *	aegis - project change supervisor
- *	Copyright (C) 1997 Peter Miller;
+ *	Copyright (C) 1997, 1999 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -20,7 +20,7 @@
  * MANIFEST: functions to walk parallel directory trees
  */
 
-#include <errno.h>
+#include <ac/errno.h>
 #include <sys/types.h>
 #include <sys/stat.h>
 
