@@ -1,6 +1,6 @@
 /*
  *	aegis - project change supervisor
- *	Copyright (C) 1997, 1999, 2001 Peter Miller;
+ *	Copyright (C) 1997 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -20,8 +20,6 @@
  * MANIFEST: functions to manipulate relative comparisons
  */
 
-#include <ac/string.h>
-
 #include <aer/value/boolean.h>
 #include <aer/value/error.h>
 #include <aer/value/integer.h>
@@ -173,8 +171,8 @@ lt_evaluate(tp, path, st)
 		 * give up on this one
 		 */
 		scp = sub_context_new();
-		sub_var_set_charstar(scp, "Name1", lv1->method->name);
-		sub_var_set_charstar(scp, "Name2", rv1->method->name);
+		sub_var_set(scp, "Name1", "%s", lv1->method->name);
+		sub_var_set(scp, "Name2", "%s", rv1->method->name);
 		s =
 			subst_intl
 			(
@@ -352,8 +350,8 @@ le_evaluate(tp, path, st)
 		 * give up on this one
 		 */
 		scp = sub_context_new();
-		sub_var_set_charstar(scp, "Name1", lv1->method->name);
-		sub_var_set_charstar(scp, "Name2", rv1->method->name);
+		sub_var_set(scp, "Name1", "%s", lv1->method->name);
+		sub_var_set(scp, "Name2", "%s", rv1->method->name);
 		s =
 			subst_intl
 			(
@@ -531,8 +529,8 @@ gt_evaluate(tp, path, st)
 		 * give up on this one
 		 */
 		scp = sub_context_new();
-		sub_var_set_charstar(scp, "Name1", lv1->method->name);
-		sub_var_set_charstar(scp, "Name2", rv1->method->name);
+		sub_var_set(scp, "Name1", "%s", lv1->method->name);
+		sub_var_set(scp, "Name2", "%s", rv1->method->name);
 		s =
 			subst_intl
 			(
@@ -710,8 +708,8 @@ ge_evaluate(tp, path, st)
 		 * give up on this one
 		 */
 		scp = sub_context_new();
-		sub_var_set_charstar(scp, "Name1", lv1->method->name);
-		sub_var_set_charstar(scp, "Name2", rv1->method->name);
+		sub_var_set(scp, "Name1", "%s", lv1->method->name);
+		sub_var_set(scp, "Name2", "%s", rv1->method->name);
 		s =
 			subst_intl
 			(
@@ -887,8 +885,8 @@ eq_evaluate(tp, path, st)
 		 * give up on this one
 		 */
 		scp = sub_context_new();
-		sub_var_set_charstar(scp, "Name1", lv1->method->name);
-		sub_var_set_charstar(scp, "Name2", rv1->method->name);
+		sub_var_set(scp, "Name1", "%s", lv1->method->name);
+		sub_var_set(scp, "Name2", "%s", rv1->method->name);
 		s =
 			subst_intl
 			(
@@ -1064,8 +1062,8 @@ ne_evaluate(tp, path, st)
 		 * give up on this one
 		 */
 		scp = sub_context_new();
-		sub_var_set_charstar(scp, "Name1", lv1->method->name);
-		sub_var_set_charstar(scp, "Name2", rv1->method->name);
+		sub_var_set(scp, "Name1", "%s", lv1->method->name);
+		sub_var_set(scp, "Name2", "%s", rv1->method->name);
 		s =
 			subst_intl
 			(
