@@ -1,6 +1,6 @@
 /*
  *	aegis - project change supervisor
- *	Copyright (C) 1991, 1992, 1993, 1994, 1995, 1996, 1997, 1998 Peter Miller;
+ *	Copyright (C) 1991, 1992, 1993, 1994, 1995, 1996, 1997, 1998, 1999 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -20,17 +20,17 @@
  * MANIFEST: functions to implement copy file
  */
 
-#include <stdio.h>
+#include <ac/stdio.h>
 #include <ac/stdlib.h>
 #include <ac/unistd.h>
 #include <ac/libintl.h>
 
 #include <aecp.h>
-#include <ael.h>
+#include <ael/project/files.h>
 #include <arglex2.h>
 #include <commit.h>
 #include <change_bran.h>
-#include <change_file.h>
+#include <change/file.h>
 #include <error.h>
 #include <file.h>
 #include <gettime.h>
@@ -40,7 +40,7 @@
 #include <os.h>
 #include <progname.h>
 #include <project.h>
-#include <project_file.h>
+#include <project/file.h>
 #include <project_hist.h>
 #include <sub.h>
 #include <trace.h>
@@ -282,6 +282,10 @@ copy_file_independent()
 			case arglex_token_string:
 				branch = arglex_value.alv_string;
 				break;
+
+			case arglex_token_stdio:
+				branch = "";
+				break;
 			}
 			break;
 
@@ -461,7 +465,7 @@ copy_file_independent()
 			++number_of_errors;
 			continue;
 		}
-		project_file_dir(pp2, s2, &wl_in, &wl_out);
+		project_file_directory_query(pp2, s2, &wl_in, &wl_out);
 		if (delta_date != (time_t)-1)
 			string_list_append_list(&wl_in, &wl_out);
 		if (wl_in.nstrings)
@@ -900,6 +904,10 @@ copy_file_main()
 			case arglex_token_string:
 				branch = arglex_value.alv_string;
 				break;
+
+			case arglex_token_stdio:
+				branch = "";
+				break;
 			}
 			break;
 
@@ -1146,7 +1154,7 @@ copy_file_main()
 			++number_of_errors;
 			continue;
 		}
-		project_file_dir(pp2, s2, &wl_in, &wl_out);
+		project_file_directory_query(pp2, s2, &wl_in, &wl_out);
 		if (delta_date != (time_t)-1)
 			string_list_append_list(&wl_in, &wl_out);
 		if (wl_in.nstrings)
