@@ -1,6 +1,6 @@
 /*
  *	aegis - project change supervisor
- *	Copyright (C) 1991, 1992, 1993, 1994, 1995, 1996, 1997, 1998 Peter Miller;
+ *	Copyright (C) 1991, 1992, 1993, 1994, 1995, 1996, 1997, 1998, 1999 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -20,16 +20,16 @@
  * MANIFEST: difference a change
  */
 
-#include <stdio.h>
+#include <ac/stdio.h>
 #include <ac/stdlib.h>
 #include <ac/time.h>
 #include <ac/unistd.h>
 
 #include <aed.h>
-#include <ael.h>
+#include <ael/change/files.h>
 #include <arglex2.h>
 #include <change_bran.h>
-#include <change_file.h>
+#include <change/file.h>
 #include <col.h>
 #include <commit.h>
 #include <error.h>
@@ -39,7 +39,7 @@
 #include <os.h>
 #include <progname.h>
 #include <project.h>
-#include <project_file.h>
+#include <project/file.h>
 #include <sub.h>
 #include <trace.h>
 #include <undo.h>
@@ -153,7 +153,7 @@ anticipate(project_name, change_number, branch, cn2, log_style, wl)
 	char		*branch;
 	long		cn2;
 	log_style_ty	log_style;
-	string_list_ty		*wl;
+	string_list_ty	*wl;
 {
 	string_ty	*dd1;
 	string_ty	*dd2;
@@ -414,11 +414,9 @@ anticipate(project_name, change_number, branch, cn2, log_style, wl)
 			output = change_file_path(cp, s1);
 			assert(output);
 			input = str_format("%S,B", output);
-			change_become(cp);
+			user_become(up);
 			os_rename(output, input);
-			undo_unlink_errok(output);
-			undo_rename(input, output);
-			change_become_undo();
+			user_become_undo();
 		}
 		else
 		{
@@ -719,6 +717,10 @@ difference_main()
 			case arglex_token_string:
 				branch = arglex_value.alv_string;
 				break;
+
+			case arglex_token_stdio:
+				branch = "";
+				break;
 			}
 			break;
 
@@ -988,7 +990,7 @@ difference_main()
 			string_list_ty		wl_in;
 
 			s1 = wl.string[j];
-			change_file_dir(cp, s1, &wl_in, 0);
+			change_file_directory_query(cp, s1, &wl_in, 0);
 			if (wl_in.nstrings)
 				string_list_append_list_unique(&wl2, &wl_in);
 			else if (change_file_find(cp, s1))
@@ -1233,8 +1235,6 @@ difference_main()
 				trace_string(curfile->str_text);
 				user_become(diff_user_p);
 				os_rename(outname, curfile);
-				undo_unlink_errok(outname);
-				undo_rename(curfile, outname);
 				user_become_undo();
 			}
 			else
@@ -1482,7 +1482,12 @@ difference_main()
 			 * changed.
 			 */
 			if (src1_data->action != file_action_remove && !integrating)
+			{
 				change_file_fingerprint_check(cp, src1_data);
+				assert(src1_data->file_fp);
+				assert(src1_data->file_fp->youngest > 0);
+				assert(src1_data->file_fp->oldest > 0);
+			}
 
 			/*
 			 * All change files have a difference file,
@@ -1491,9 +1496,9 @@ difference_main()
 			 */
 			user_become(diff_user_p);
 			if (integrating)
-				ignore = change_fingerprint_same(src1_data->idiff_file_fp, path_d);
+				ignore = change_fingerprint_same(src1_data->idiff_file_fp, path_d, 0);
 			else
-				ignore = change_fingerprint_same(src1_data->diff_file_fp, path_d);
+				ignore = change_fingerprint_same(src1_data->diff_file_fp, path_d, 0);
 			user_become_undo();
 			if (ignore)
 			{
@@ -1594,7 +1599,7 @@ difference_main()
 						src1_data->idiff_file_fp =
 						       fingerprint_type.alloc();
 					src1_data->idiff_file_fp->youngest = 0;
-					change_fingerprint_same(src1_data->idiff_file_fp, path_d);
+					change_fingerprint_same(src1_data->idiff_file_fp, path_d, 0);
 				}
 				else
 				{
@@ -1602,7 +1607,7 @@ difference_main()
 						src1_data->diff_file_fp =
 						       fingerprint_type.alloc();
 					src1_data->diff_file_fp->youngest = 0;
-					change_fingerprint_same(src1_data->diff_file_fp, path_d);
+					change_fingerprint_same(src1_data->diff_file_fp, path_d, 0);
 				}
 				user_become_undo();
 				break;
