@@ -1,6 +1,6 @@
 /*
  *	aegis - project change supervisor
- *	Copyright (C) 1991, 1992, 1993, 1994, 1995, 1996, 1997, 1998 Peter Miller;
+ *	Copyright (C) 1991, 1992, 1993, 1994, 1995, 1996, 1997, 1998, 1999 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -20,7 +20,7 @@
  * MANIFEST: functions for implementing integrate begin
  */
 
-#include <stdio.h>
+#include <ac/stdio.h>
 #include <ac/stdlib.h>
 #include <ac/string.h>
 #include <ac/time.h>
@@ -30,22 +30,23 @@
 #include <sys/stat.h>
 
 #include <aeib.h>
-#include <ael.h>
+#include <ael/change/by_state.h>
 #include <arglex2.h>
 #include <commit.h>
 #include <change.h>
 #include <change_bran.h>
-#include <change_file.h>
+#include <change/file.h>
 #include <dir.h>
 #include <error.h>
 #include <file.h>
+#include <gmatch.h>
 #include <help.h>
 #include <lock.h>
 #include <log.h>
 #include <progname.h>
 #include <os.h>
 #include <project.h>
-#include <project_file.h>
+#include <project/file.h>
 #include <project_hist.h>
 #include <sub.h>
 #include <trace.h>
@@ -133,6 +134,30 @@ remove_comma_d_if_present(s)
 }
 
 
+static int isa_suppressed_filename _((change_ty *, string_ty *));
+
+static int
+isa_suppressed_filename(cp, fn)
+	change_ty	*cp;
+	string_ty	*fn;
+{
+	pconf		pconf_data;
+	pconf_integrate_begin_exceptions_list p;
+	size_t		j;
+
+	pconf_data = change_pconf_get(cp, 1);
+	p = pconf_data->integrate_begin_exceptions;
+	if (!p)
+		return 0;
+	for (j = 0; j < p->length; ++j)
+	{
+		if (gmatch(p->list[j]->str_text, fn->str_text))
+			return 1;
+	}
+	return 0;
+}
+
+
 static void link_tree_callback_minimum _((void *, dir_walk_message_ty,
 	string_ty *, struct stat *));
 
@@ -230,6 +255,21 @@ st = %08lX)\n{\n"/*}*/, message, path, st));
 			str_free(s1short);
 			break;
 		}
+
+		/*
+		 * Don't link a suppressed file.
+		 * BUT keep primary source files and their diff files.
+		 */
+		if
+		(
+			!project_file_find(cp->pp, s1short)
+		&&
+			isa_suppressed_filename(cp, s1short)
+		)
+		{
+			str_free(s1short);
+			break;
+		}
 		str_free(s1short);
 
 		/*
@@ -238,9 +278,29 @@ st = %08lX)\n{\n"/*}*/, message, path, st));
 		trace(("ln %s %s\n", path->str_text, s2->str_text));
 		os_link(path, s2);
 		if (!project_file_find(cp->pp, s1))
-			os_chmod(s2, (st->st_mode | 0644) & ~0022 & ~change_umask(cp));
+		{
+			/*
+			 * If it is not a source file, it could be owned
+			 * by some other user, and we have no control
+			 * over its owner or mode.  Report a warning if
+			 * we can't change the mode.
+			 *
+			 * Also, we leave it writable if it is already.
+			 * This is normal for generated files.
+			 */
+			os_chmod_errok(s2, (st->st_mode | 0644) & ~0022 & ~change_umask(cp));
+		}
 		else
+		{
+			/*
+			 * Source files, on the other hand, should always
+			 * be owned by us, and thus always chmod(2)able
+			 * by us.  Have a hissy-fit if they aren't.
+			 * 
+			 * Also, source files should be read-only.
+			 */
 			os_chmod(s2, (st->st_mode | 0444) & ~0222 & ~change_umask(cp));
+		}
 
 		/*
 		 * Update the modify time of the linked file.  On a
@@ -331,6 +391,21 @@ st = %08lX)\n{\n"/*}*/, message, path, st));
 			str_free(s1short);
 			break;
 		}
+
+		/*
+		 * Don't link a suppressed file.
+		 * BUT keep primary source files and their diff files.
+		 */
+		if
+		(
+			!project_file_find(cp->pp, s1short)
+		&&
+			isa_suppressed_filename(cp, s1short)
+		)
+		{
+			str_free(s1short);
+			break;
+		}
 		str_free(s1short);
 
 		/*
@@ -338,9 +413,29 @@ st = %08lX)\n{\n"/*}*/, message, path, st));
 		 */
 		os_link(path, s2);
 		if (!src)
-			os_chmod(s2, (st->st_mode | 0644) & ~0022 & ~change_umask(cp));
+		{
+			/*
+			 * If it is not a source file, it could be owned
+			 * by some other user, and we have no control
+			 * over its owner or mode.  Report a warning if
+			 * we can't change the mode.
+			 *
+			 * Also, we leave it writable if it is already.
+			 * This is normal for generated files.
+			 */
+			os_chmod_errok(s2, (st->st_mode | 0644) & ~0022 & ~change_umask(cp));
+		}
 		else
+		{
+			/*
+			 * Source files, on the other hand, should always
+			 * be owned by us, and thus always chmod(2)able
+			 * by us.  Have a hissy-fit if they aren't.
+			 * 
+			 * Also, source files should be read-only.
+			 */
 			os_chmod(s2, (st->st_mode | 0444) & ~0222 & ~change_umask(cp));
+		}
 
 		/*
 		 * Update the modify time of the linked file.  On a
@@ -485,6 +580,21 @@ st = %08lX)\n{\n"/*}*/, message, path, st));
 			str_free(s1short);
 			break;
 		}
+
+		/*
+		 * Don't copy a suppressed file.
+		 * BUT keep primary source files and their diff files.
+		 */
+		if
+		(
+			!project_file_find(cp->pp, s1short)
+		&&
+			isa_suppressed_filename(cp, s1short)
+		)
+		{
+			str_free(s1short);
+			break;
+		}
 		str_free(s1short);
 
 		/*
@@ -595,6 +705,21 @@ copy_tree_callback(arg, message, path, st)
 			str_free(s1short);
 			break;
 		}
+
+		/*
+		 * Don't copy a suppressed file.
+		 * BUT keep primary source files and their diff files.
+		 */
+		if
+		(
+			!project_file_find(cp->pp, s1short)
+		&&
+			isa_suppressed_filename(cp, s1short)
+		)
+		{
+			str_free(s1short);
+			break;
+		}
 		str_free(s1short);
 
 		/*
@@ -900,7 +1025,7 @@ integrate_begin_main()
 			continue;
 
 		s1 = change_file_path(cp, src_data->file_name);
-		if (!change_fingerprint_same(src_data->file_fp, s1))
+		if (!change_fingerprint_same(src_data->file_fp, s1, 0))
 		{
 			sub_context_ty	*scp;
 
@@ -910,9 +1035,11 @@ integrate_begin_main()
 			sub_context_delete(scp);
 			errs++;
 		}
+		assert(src_data->file_fp->youngest > 0);
+		assert(src_data->file_fp->oldest > 0);
 
 		s2 = str_format("%S,D", s1);
-		if (!change_fingerprint_same(src_data->diff_file_fp, s2))
+		if (!change_fingerprint_same(src_data->diff_file_fp, s2, 0))
 		{
 			sub_context_ty	*scp;
 
@@ -922,6 +1049,8 @@ integrate_begin_main()
 			sub_context_delete(scp);
 			errs++;
 		}
+		assert(src_data->diff_file_fp->youngest > 0);
+		assert(src_data->diff_file_fp->oldest > 0);
 		str_free(s1);
 		str_free(s2);
 	}
