@@ -1,6 +1,6 @@
 /*
  *	aegis - project change supervisor
- *	Copyright (C) 1998 Peter Miller;
+ *	Copyright (C) 1998, 1999 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -79,4 +79,29 @@
 # undef HAVE_WIDEC_H
 #endif
 
+/*
+ * Need to define _POSIX_SOURCE on Linux, in order to get the fdopen,
+ * fileno, popen and pclose function prototypes.
+ */
+#ifdef __linux__
+#ifndef _POSIX_SOURCE
+#define _POSIX_SOURCE
+#endif
+#ifndef _GNU_SOURCE
+#define _GNU_SOURCE
+#endif
+#ifndef _BSD_SOURCE
+#define _BSD_SOURCE
+#endif
+#endif
+
+/*
+ * The SINGLE_USER define may be exploited to create a single-user version
+ * of Aegis.  It is mostly used for testing, but also for Windows NT,
+ * as the security there is stuffed.
+ */
+#if defined(__CYGWIN__) || defined(__CYGWIN32__) || defined(__NUTC__)
+#define SINGLE_USER
+#endif
+
 #endif /* COMMON_CONFIG_MESSY_H */
