@@ -1,6 +1,6 @@
 /*
  *	aegis - project change supervisor
- *	Copyright (C) 1994, 1995 Peter Miller;
+ *	Copyright (C) 1994, 1995, 1999 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -26,10 +26,10 @@
 #include <ac/stdarg.h>
 #include <main.h>
 
-char *mprintf _((char *fmt, ...));
-char *mprintf_errok _((char *fmt, ...));
-char *vmprintf _((char *fmt, va_list));
-char *vmprintf_errok _((char *fmt, va_list));
-struct string_ty *vmprintf_str _((char *fmt, va_list));
+char *mprintf _((const char *fmt, ...));
+char *mprintf_errok _((const char *fmt, ...));
+char *vmprintf _((const char *fmt, va_list));
+char *vmprintf_errok _((const char *fmt, va_list));
+struct string_ty *vmprintf_str _((const char *fmt, va_list));
 
 #endif /* COMMON_MPRINTF_H */
