@@ -1,7 +1,7 @@
 #!/bin/sh
 #
 #	aegis - project change supervisor
-#	Copyright (C) 1998 Peter Miller;
+#	Copyright (C) 1998, 1999 Peter Miller;
 #	All rights reserved.
 #
 #	This program is free software; you can redistribute it and/or modify
@@ -21,7 +21,11 @@
 # MANIFEST: shell script to rpm-build
 #
 case $# in
+3)
+	icon=$3
+	;;
 2)
+	icon=
 	;;
 *)
 	echo "Usage: $0 tmp-dir tarball" 1>&2
@@ -35,6 +39,10 @@ tarball=$2
 mkdir -p $tmp/BUILD $tmp/BUILD_ROOT $tmp/RPMS/i386 \
 	$tmp/SOURCES $tmp/SPECS $tmp/SRPMS
 
+# copy the icon into the SOURCES directory
+# if an icon was specified
+test "z$icon" != "z" && cp $icon $tmp/SOURCES/.
+
 here=`pwd`/$tmp
 cat > $tmp/rpmrc << fubar
 builddir: $here/BUILD
