@@ -1,6 +1,6 @@
 /*
  *	aegis - project change supervisor
- *	Copyright (C) 1995, 1996, 1997, 1998 Peter Miller;
+ *	Copyright (C) 1995, 1996, 1997, 1998, 1999 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -23,13 +23,14 @@
 #include <ac/stdlib.h>
 
 #include <change_bran.h>
-#include <change_file.h>
+#include <change/file.h>
 #include <error.h>
 #include <fstrcmp.h>
 #include <interval.h>
 #include <project.h>
 #include <sub.h>
 #include <trace.h>
+#include <skip_unlucky.h>
 #include <str_list.h>
 #include <zero.h>
 
@@ -1482,10 +1483,140 @@ change_branch_minimum_change_number_set(cp, n)
 }
 
 
-long
-change_branch_next_change_number(cp, skip)
+int
+change_branch_reuse_change_numbers_get(cp)
 	change_ty	*cp;
-	int		skip;
+{
+	cstate		cstate_data;
+	cstate_branch	bp;
+
+	cstate_data = change_cstate_get(cp);
+	bp = cstate_data->branch;
+	assert(bp);
+	if (!bp)
+		return 1;
+	if (!(bp->mask & cstate_branch_reuse_change_numbers_mask))
+	{
+		bp->reuse_change_numbers = 1;
+		bp->mask |= cstate_branch_reuse_change_numbers_mask;
+	}
+	return bp->reuse_change_numbers;
+}
+
+
+void
+change_branch_reuse_change_numbers_set(cp, n)
+	change_ty	*cp;
+	int		n;
+{
+	cstate		cstate_data;
+	cstate_branch	bp;
+
+	cstate_data = change_cstate_get(cp);
+	bp = cstate_data->branch;
+	assert(bp);
+	bp->reuse_change_numbers = !!n;
+	bp->mask |= cstate_branch_reuse_change_numbers_mask;
+}
+
+
+long
+change_branch_minimum_branch_number_get(cp)
+	change_ty	*cp;
+{
+	cstate		cstate_data;
+	cstate_branch	bp;
+
+	cstate_data = change_cstate_get(cp);
+	bp = cstate_data->branch;
+	assert(bp);
+	if (!bp)
+		return 1;
+	if (bp->minimum_branch_number < 1)
+		bp->minimum_branch_number = 1;
+	return bp->minimum_branch_number;
+}
+
+
+void
+change_branch_minimum_branch_number_set(cp, n)
+	change_ty	*cp;
+	long		n;
+{
+	cstate		cstate_data;
+	cstate_branch	bp;
+
+	cstate_data = change_cstate_get(cp);
+	bp = cstate_data->branch;
+	assert(bp);
+	if (n < 1)
+		n = 1;
+	bp->minimum_branch_number = n;
+}
+
+
+int
+change_branch_skip_unlucky_get(cp)
+	change_ty	*cp;
+{
+	cstate		cstate_data;
+	cstate_branch	bp;
+
+	cstate_data = change_cstate_get(cp);
+	bp = cstate_data->branch;
+	assert(bp);
+	return (bp && bp->skip_unlucky);
+}
+
+
+void
+change_branch_skip_unlucky_set(cp, n)
+	change_ty	*cp;
+	int		n;
+{
+	cstate		cstate_data;
+	cstate_branch	bp;
+
+	cstate_data = change_cstate_get(cp);
+	bp = cstate_data->branch;
+	assert(bp);
+	bp->skip_unlucky = !!n;
+}
+
+
+int
+change_branch_compress_database_get(cp)
+	change_ty	*cp;
+{
+	cstate		cstate_data;
+	cstate_branch	bp;
+
+	cstate_data = change_cstate_get(cp);
+	bp = cstate_data->branch;
+	assert(bp);
+	return (bp && bp->compress_database);
+}
+
+
+void
+change_branch_compress_database_set(cp, n)
+	change_ty	*cp;
+	int		n;
+{
+	cstate		cstate_data;
+	cstate_branch	bp;
+
+	cstate_data = change_cstate_get(cp);
+	bp = cstate_data->branch;
+	assert(bp);
+	bp->compress_database = !!n;
+}
+
+
+long
+change_branch_next_change_number(cp, is_a_change)
+	change_ty	*cp;
+	int		is_a_change;
 {
 	cstate		cstate_data;
 	cstate_branch_change_list lp;
@@ -1495,6 +1626,7 @@ change_branch_next_change_number(cp, skip)
 	interval_ty	*ip3;
 	size_t		j, k;
 	long		min;
+	int		reuse;
 
 	trace(("change_branch_next_change_number(cp = %8.8lX)\n{\n"/*}*/,
 		(long)cp));
@@ -1528,16 +1660,46 @@ change_branch_next_change_number(cp, skip)
 	 * This avoids zero.  If the user wants a zero-numbered change,
 	 * she must ask for it.
 	 */
-	if (skip)
+	if (is_a_change)
 		min = change_branch_minimum_change_number_get(cp);
 	else
-		min = 1;
+		min = change_branch_minimum_branch_number_get(cp);
 	ip2 = interval_create_range(min, TRUNK_CHANGE_NUMBER - 1);
 	ip3 = interval_difference(ip2, ip1);
 	interval_free(ip1);
 	interval_free(ip2);
 	assert(ip3->length);
-	change_number = ip3->data[0];
+
+	/*
+	 * The result is the minimum acceptable number in the interval.
+	 * But !reuse means the first number in the last interval.
+	 */
+	reuse = !is_a_change || change_branch_reuse_change_numbers_get(cp);
+	if (!change_branch_skip_unlucky_get(cp))
+	{
+		if (reuse)
+			change_number = ip3->data[0];
+		else
+			change_number = ip3->data[ip3->length - 2];
+	}
+	else
+	{
+		for (;;)
+		{
+			if (reuse)
+				change_number = ip3->data[0];
+			else
+				change_number = ip3->data[ip3->length - 2];
+			min = skip_unlucky(change_number);
+			if (min == change_number)
+				break;
+			ip1 = interval_create_range(change_number, min - 1);
+			ip2 = interval_difference(ip3, ip1);
+			interval_free(ip3);
+			interval_free(ip1);
+			ip3 = ip2;
+		}
+	}
 	interval_free(ip3);
 	trace(("return %ld;\n", change_number));
 	trace((/*{*/"}\n"));
@@ -1711,6 +1873,8 @@ change_branch_delta_date_to_edit(pp, delta_date, file_name)
 	bp = cstate_data->branch;
 	assert(bp);
 	first_time_seen = 1;
+	if (!bp->history)
+		bp->history = cstate_branch_history_list_type.alloc();
 	for (j = 0; j < bp->history->length; ++j)
 	{
 		cstate_branch_history hp;
