@@ -1,6 +1,6 @@
 /*
  *	aegis - project change supervisor
- *	Copyright (C) 1991, 1992, 1993, 1994, 1995, 1997 Peter Miller;
+ *	Copyright (C) 1991, 1992, 1993, 1994, 1995, 1997, 1999 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -20,6 +20,7 @@
  * MANIFEST: functions to walk directory trees
  */
 
+#include <config.h>
 #include <sys/types.h>
 #include <sys/stat.h>
 
@@ -48,7 +49,7 @@ dir_walk(path, callback, arg)
 	trace(("dir_walk(path = %08lX, callback = %08lX, \
 arg = %08lX)\n{\n"/*}*/, path, callback, arg));
 	trace_string(path->str_text);
-#ifdef S_IFLNK
+#if defined(S_IFLNK) || defined(S_ISLNK)
 	if (glue_lstat(path->str_text, &st))
 	{
 		sub_context_ty	*scp;
@@ -108,7 +109,7 @@ arg = %08lX)\n{\n"/*}*/, path, callback, arg));
 		callback(arg, dir_walk_file, path, &st);
 		break;
 
-#ifdef S_IFLNK
+#if defined(S_IFLNK) || defined(S_ISLNK)
 	case S_IFLNK:
 		callback(arg, dir_walk_symlink, path, &st);
 		break;
