@@ -1,6 +1,6 @@
 /*
  *	aegis - project change supervisor
- *	Copyright (C) 1993, 1994, 1995, 1997, 1998 Peter Miller;
+ *	Copyright (C) 1993, 1994, 1995, 1997, 1998, 1999 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -36,11 +36,10 @@
  * which is broken.  These systems will also need to use this glue.
  */
 
-#include <errno.h>
-#include <signal.h>
 #include <ac/stdio.h>
 #include <ac/stdlib.h>
 #include <ac/string.h>
+#include <ac/errno.h>
 #include <signal.h>
 
 #include <sys/types.h>
@@ -63,7 +62,6 @@
 #include <lock.h> /* for lock_release_child */
 #include <mem.h>
 #include <os.h>
-#include <r250.h>
 #include <sub.h>
 #include <trace.h>
 #include <undo.h>
@@ -84,7 +82,6 @@ enum
 	command_file_compare,
 	command_file_fingerprint,
 	command_getcwd,
-	command_junkfile,
 	command_link,
 	command_lstat,
 	command_mkdir,
@@ -152,7 +149,6 @@ command_name(n)
 	case command_file_compare: return "file_compare";
 	case command_file_fingerprint: return "file_fingerprint";
 	case command_getcwd:	return "getcwd";
-	case command_junkfile:	return "junkfile";
 	case command_link:	return "link";
 	case command_lstat:	return "lstat";
 	case command_mkdir:	return "mkdir";
@@ -563,14 +559,6 @@ proxy(rd_fd, wr_fd)
 			mem_free(path1);
 			break;
 
-		case command_junkfile:
-			path = get_string(command);
-			result = junkfile(path);
-			if (result)
-				result = errno;
-			put_int(reply, result);
-			break;
-
 		case command_link:
 			path = get_string(command);
 			path1 = mem_copy_string(path);
@@ -1284,30 +1272,6 @@ glue_unlink(path)
 }
 
 
-int
-glue_junkfile(path)
-	char		*path;
-{
-	proxy_ty	*pp;
-	int		result;
-
-	trace(("glue_junkfile()\n{\n"/*}*/));
-	pp = proxy_find();
-	fputc(command_junkfile, pp->command);
-	put_string(pp->command, path);
-	end_of_command(pp);
-	result = get_int(pp->reply);
-	if (result)
-	{
-		errno = result;
-		result = -1;
-	}
-	trace(("return %d; /* errno = %d */\n", result, errno));
-	trace((/*{*/"}\n"));
-	return result;
-}
-
-
 int
 glue_link(p1, p2)
 	char		*p1;
@@ -1808,9 +1772,6 @@ glue_fputc(c, fp)
 	/*
 	 * locate the appropriate proxy
 	 */
-#if 0
-	trace(("glue_fputc()\n{\n"/*}*/));
-#endif
 	result = EOF;
 	gfp = (glue_file_ty *)fp;
 	assert(gfp->guard1 == GUARD1);
@@ -1877,10 +1838,108 @@ glue_fputc(c, fp)
 	 * here for all exits
 	 */
 	done:
-#if 0
-	trace(("return %d; /* errno = %d */\n", result, errno));
-	trace((/*{*/"}\n"));
-#endif
+	return result;
+}
+
+
+int
+glue_fwrite(buf, len1, len2, fp)
+	char		*buf;
+	long		len1;
+	long		len2;
+	FILE		*fp;
+{
+	proxy_ty	*pp;
+	glue_file_ty	*gfp;
+	int		result;
+	long		len;
+
+	/*
+	 * Leave the standard file streams alone.
+	 * There is a chance these will be seen here.
+	 */
+	if (fp == stdout || fp == stdin || fp == stderr)
+		return fwrite(buf, len1, len2, fp);
+
+	/*
+	 * locate the appropriate proxy
+	 */
+	result = EOF;
+	gfp = (glue_file_ty *)fp;
+	assert(gfp->guard1 == GUARD1);
+	assert(gfp->guard2 == GUARD2);
+	pp = gfp->pp;
+
+	/*
+	 * if the stream is in an error state,
+	 * or we were asked to do something stupid,
+	 * return the error
+	 */
+	if (gfp->errno_sequester)
+	{
+		errno = gfp->errno_sequester;
+		goto done;
+	}
+	if (gfp->fmode == O_RDONLY)
+	{
+		gfp->errno_sequester = EINVAL;
+		errno = EINVAL;
+		goto done;
+	}
+
+	/*
+	 * push the bytes into the buffer
+	 */
+	len = len1 * len2;
+	while (len > 0)
+	{
+		int c = (unsigned char)*buf++;
+		--len;
+
+		/*
+		 * if there is no room in the buffer,
+		 * flush it to the proxy
+		 */
+		assert(gfp->buffer_pos);
+		if (gfp->buffer_pos >= gfp->buffer_end)
+		{
+			long	nbytes;
+			long	nbytes2;
+	
+			fputc(command_write, pp->command);
+			put_int(pp->command, gfp->fd);
+			nbytes = gfp->buffer_pos - gfp->buffer;
+			put_long(pp->command, nbytes);
+			put_binary(pp->command, gfp->buffer, nbytes);
+			end_of_command(pp);
+			nbytes2 = get_long(pp->reply);
+			if (nbytes2 < 0)
+			{
+				gfp->errno_sequester = get_int(pp->reply);
+				errno = gfp->errno_sequester;
+				goto done;
+			}
+			if (nbytes2 != nbytes)
+			{
+				gfp->errno_sequester = EIO;
+				errno = EIO;
+				goto done;
+			}
+			gfp->buffer_pos = gfp->buffer;
+			gfp->buffer_end = gfp->buffer + sizeof(gfp->buffer);
+		}
+	
+		/*
+		 * stash the character
+		 */
+		*gfp->buffer_pos++ = c;
+	}
+	result = len1;
+
+	/*
+	 * here for all exits
+	 */
+	done:
 	return result;
 }
 
@@ -2373,86 +2432,6 @@ copyfile(src, dst)
 }
 
 
-/*
- * NAME
- *	junkfile - junk a file
- *
- * SYNOPSIS
- *	int junkfile(char *src, char *dst);
- *
- * DESCRIPTION
- *	The junkfile function creates a file and fills it
- *	with 1K of garbage.  This is (mostly) to ensure that if
- *	removed files are used during development build,
- *	they will generate errors.
- *
- * ARGUMENTS
- *	path	- pathname of junk file
- *
- * RETURNS
- *	0	on success
- *	-1	on error, setting errno appropriately
- */
-
-int
-junkfile(path)
-	char		*path;
-{
-	static char	junk[] = "!#$%&()*+,-./:;<=>?@[]^_`{|}~";
-	char		buffer[1024];
-	char		*bp;
-	int		fd;
-	int		err;
-	int		result;
-	int		jlen;
-	long		nbytes;
-
-	/*
-	 * create a buffer full of gibberish
-	 */
-	trace(("junkfile(\"%s\")\n{\n"/*}*/, path));
-	os_interrupt_cope();
-	jlen = strlen(junk);
-	for (bp = buffer; bp < ENDOF(buffer); ++bp)
-	{
-		if (((bp - buffer) % 64) == 63)
-			*bp = '\n';
-		else
-			*bp = junk[r250() % jlen];
-	}
-	buffer[SIZEOF(buffer) - 1] = '\n';
-
-	fd = creat(path, 0666);
-	if (fd >= 0)
-	{
-		err = 0;
-		nbytes = write(fd, buffer, sizeof(buffer));
-		if (nbytes < 0)
-			err = errno;
-		if (nbytes == 0)
-			err = EIO; /* weird device, probably */
-		if (close(fd) && !err)
-			err = errno;
-		if (err)
-		{
-			errno = err;
-			result = -1;
-		}
-		else
-			result = 0;
-	}
-	else
-		result = -1;
-
-	/*
-	 * here for all exits
-	 */
-	trace(("return %d; /* errno = %d */\n", result, errno));
-	trace((/*{*/"}\n"));
-	return result;
-}
-
-
 /*
  * NAME
  *	catfile - copy a file
