@@ -1,6 +1,6 @@
 /*
  *	aegis - project change supervisor
- *	Copyright (C) 1993, 1994 Peter Miller.
+ *	Copyright (C) 1993, 1994, 1999 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -17,13 +17,13 @@
  *	along with this program; if not, write to the Free Software
  *	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
  *
- * MANIFEST: interface definition for aegis/glue.c
+ * MANIFEST: interface definition for libaegis/glue.c
  */
 
 #ifndef AEGIS_GLUE_H
 #define AEGIS_GLUE_H
 
-#include <stdio.h>
+#include <ac/stdio.h>
 
 #include <main.h>
 #include <config.h>
@@ -34,7 +34,6 @@ struct flock;
 
 int copyfile _((char *src, char *dst));
 int catfile _((char *path));
-int junkfile _((char *path));
 int read_whole_dir _((char *path, char **data, long *datalen));
 int file_compare _((char *, char *));
 int file_fingerprint _((char *path, char *buf, int max));
@@ -58,7 +57,6 @@ int glue_fgetc _((FILE *));
 FILE *glue_fopen _((char *path, char *mode));
 int glue_fputc _((int, FILE *));
 char *glue_getcwd _((char *buf, int max));
-int glue_junkfile _((char *path));
 int glue_link _((char *p1, char *p2));
 int glue_lstat _((char *path, struct stat *st));
 int glue_mkdir _((char *path, int mode));
@@ -76,6 +74,7 @@ int glue_ungetc _((int, FILE *));
 int glue_unlink _((char *path));
 int glue_utime _((char *path, struct utimbuf *));
 int glue_write _((int fd, char *data, long len));
+int glue_fwrite _((char *, long, long, FILE *));
 
 
 #ifndef CONF_NO_seteuid
@@ -103,7 +102,6 @@ int glue_write _((int fd, char *data, long len));
 #define	glue_fopen	fopen
 #define	glue_fputc	putc
 #define	glue_getcwd	getcwd
-#define	glue_junkfile	junkfile
 #define	glue_link	link
 #define	glue_lstat	lstat
 #define	glue_mkdir	mkdir
@@ -121,6 +119,7 @@ int glue_write _((int fd, char *data, long len));
 #define	glue_unlink	unlink
 #define	glue_utime	utime
 #define	glue_write	write
+#define	glue_fwrite	fwrite
 
 #endif /* aegis_glue_disable */
 #endif /* CONF_NO_seteuid */
