@@ -1,6 +1,6 @@
 /*
  *	aegis - project change supervisor
- *	Copyright (C) 1991, 1992, 1993, 1994, 1995, 1996, 1997, 1998 Peter Miller;
+ *	Copyright (C) 1991, 1992, 1993, 1994, 1995, 1996, 1997, 1998, 1999 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -21,7 +21,7 @@
  */
 
 #include <ac/stdlib.h>
-#include <errno.h>
+#include <ac/errno.h>
 #include <ac/stdio.h>
 #include <ac/string.h>
 #include <ac/limits.h>
@@ -357,42 +357,6 @@ os_rmdir_tree(path)
 }
 
 
-void
-os_mkdir_between(top, extn, mode)
-	string_ty	*top;
-	string_ty	*extn;
-	int		mode;
-{
-	char		*cp;
-	string_ty	*s1;
-	string_ty	*s2;
-
-	trace(("os_mkdir_between(top = %08lX, extn = %08lX, \
-mode = 0%o)\n{\n"/*}*/, top, extn, mode));
-	trace_string(top->str_text);
-	trace_string(extn->str_text);
-	assert(top->str_text[0] == '/');
-	assert(extn->str_text[0] != '/');
-	assert(extn->str_text[extn->str_length - 1] != '/');
-	assert(extn->str_length);
-	for (cp = extn->str_text; *cp; ++cp)
-	{
-		if (*cp != '/')
-			continue;
-		s1 = str_n_from_c(extn->str_text, cp - extn->str_text);
-		s2 = str_format("%S/%S", top, s1);
-		if (!os_exists(s2))
-		{
-			os_mkdir(s2, mode);
-			undo_rmdir_errok(s2);
-		}
-		str_free(s1);
-		str_free(s2);
-	}
-	trace((/*{*/"}\n"));
-}
-
-
 void
 os_rename(a, b)
 	string_ty	*a;
@@ -539,337 +503,6 @@ os_unlink_errok(path)
 }
 
 
-/*
- * NAME
- *	os_curdir_sub - get current directory
- *
- * SYNOPSIS
- *	string_ty *os_curdir_sub(void);
- *
- * DESCRIPTION
- *	The os_curdir_sub function is used to determine the system's idea
- *	of the current directory.
- *
- * RETURNS
- *	A pointer to a string in dynamic memory is returned.
- *	A null pointer is returned on error.
- *
- * CAVEAT
- *	DO NOT use str_free() on the value returned.
- */
-
-static string_ty *os_curdir_sub _((void));
-
-static string_ty *
-os_curdir_sub()
-{
-	static string_ty	*s;
-
-	os_become_must_be_active();
-	if (!s)
-	{
-		char	buffer[2000];
-
-		if (!glue_getcwd(buffer, sizeof(buffer)))
-		{
-			sub_context_ty	*scp;
-
-			scp = sub_context_new();
-			sub_errno_set(scp);
-			fatal_intl(scp, i18n("getcwd: $errno"));
-			/* NOTREACHED */
-		}
-		assert(buffer[0] == '/');
-		s = str_from_c(buffer);
-	}
-	return s;
-}
-
-
-/*
- * NAME
- *	os_curdir - full current directory path
- *
- * SYNOPSIS
- *	string_ty *os_curdir(void);
- *
- * DESCRIPTION
- *	Os_curdir is used to determine the pathname
- *	of the current directory.  Automounter vaguaries will be elided.
- *
- * RETURNS
- *	A pointer to a string in dynamic memory is returned.
- *	A null pointer is returned on error.
- *
- * CAVEAT
- *	Use str_free() when you are done with the value returned.
- */
-
-string_ty *
-os_curdir()
-{
-	static string_ty	*result;
-
-	os_become_must_be_active();
-	if (!result)
-	{
-		string_ty	*dot;
-		
-		dot = str_from_c(".");
-		result = os_pathname(dot, 1);
-		str_free(dot);
-	}
-	return str_copy(result);
-}
-
-
-/*
- * NAME
- *	os_pathname - determine full file name
- *
- * SYNOPSIS
- *	string_ty *os_pathname(string_ty *path, int resolve);
- *
- * DESCRIPTION
- *	Os_pathname is used to determine the full path name
- *	of a partial path given.
- *
- * ARGUMENTS
- *	path	- path to canonicalize
- *	resolve	- non-zero if should resolve symlinks, 0 if not
- *
- * RETURNS
- *	pointer to dynamically allocated string.
- *
- * CAVEAT
- *	Use str_free() when you are done with the value returned.
- */
-
-string_ty *
-os_pathname(path, resolve)
-	string_ty	*path;
-	int		resolve;
-{
-	static char	*tmp;
-	static size_t	tmplen;
-	static size_t	ipos;
-	static size_t	opos;
-	int		c;
-	int		found;
-#ifdef S_IFLNK
-	int		loop;
-#endif
-
-	/*
-	 * Change relative pathnames to absolute
-	 */
-	trace(("os_pathname(path = %08lX)\n{\n"/*}*/, path));
-	if (!path)
-		path = os_curdir();
-	if (resolve)
-		os_become_must_be_active();
-	trace_string(path->str_text);
-	if (path->str_text[0] != '/')
-		path = str_format("%S/%S", os_curdir_sub(), path);
-	else
-		path = str_copy(path);
-	if (!tmp)
-	{
-		tmplen = 200;
-		tmp = mem_alloc(tmplen);
-	}
-
-	/*
-	 * Take kinks out of the pathname
-	 */
-	ipos = 0;
-	opos = 0;
-	found = 0;
-#ifdef S_IFLNK
-	loop = 0;
-#endif
-	while (!found)
-	{
-		/*
-		 * get the next character
-		 */
-		c = path->str_text[ipos];
-		if (c)
-			ipos++;
-		else
-		{
-			found = 1;
-			c = '/';
-		}
-
-		/*
-		 * remember the normal characters
-		 * until get to slash
-		 */
-		if (c != '/')
-			goto remember;
-
-		/*
-		 * leave root alone
-		 */
-		if (!opos)
-			goto remember;
-
-		/*
-		 * "/.." -> "/"
-		 */
-		if (opos == 3 && tmp[1] == '.' && tmp[2] == '.')
-		{
-			opos = 1;
-			continue;
-		}
-
-		/*
-		 * "a//" -> "a/"
-		 */
-		if (tmp[opos - 1] == '/')
-			continue;
-
-		/*
-		 * "a/./" -> "a/"
-		 */
-		if (opos >= 2 && tmp[opos - 1] == '.' && tmp[opos - 2] == '/')
-		{
-			opos--;
-			continue;
-		}
-
-		/*
-		 * "a/b/../" -> "a/"
-		 */
-		if
-		(
-			opos > 3
-		&&
-			tmp[opos - 1] == '.'
-		&&
-			tmp[opos - 2] == '.'
-		&&
-			tmp[opos - 3] == '/'
-		)
-		{
-			opos -= 4;
-			assert(opos > 0);
-			while (tmp[opos - 1] != '/')
-				opos--;
-			continue;
-		}
-
-		/*
-		 * see if the path so far is a symbolic link
-		 */
-#ifdef S_IFLNK
-		if (resolve)
-		{
-			char		pointer[2000];
-			int		nbytes;
-			string_ty	*s;
-
-			s = str_n_from_c(tmp, opos);
-			nbytes = glue_readlink(s->str_text, pointer, sizeof(pointer) - 1);
-			if (nbytes < 0)
-			{
-				/*
-				 * probably not a symbolic link
-				 */
-				if
-				(
-					errno != ENXIO
-				&&
-					errno != EINVAL
-				&& 
-					errno != ENOENT
-				&& 
-					errno != ENOTDIR
-				)
-				{
-					sub_context_ty	*scp;
-
-					scp = sub_context_new();
-					sub_errno_set(scp);
-					sub_var_set(scp, "File_Name", "%S", s);
-					fatal_intl(scp, i18n("readlink $filename: $errno"));
-					/* NOTREACHED */
-				}
-				str_free(s);
-			}
-			else
-			{
-				string_ty	*newpath;
-	
-				if (nbytes == 0)
-				{
-					pointer[0] = '.';
-					nbytes = 1;
-				}
-				if (++loop > 1000)
-				{
-					sub_context_ty	*scp;
-
-					scp = sub_context_new();
-					sub_errno_setx(scp, ELOOP);
-					sub_var_set(scp, "File_Name", "%S", s);
-					fatal_intl(scp, i18n("readlink $filename: $errno"));
-					/* NOTREACHED */
-				}
-				pointer[nbytes] = 0;
-	
-				str_free(s);
-				if (pointer[0] == '/')
-					tmp[1] = 0;
-				else
-				{
-					while (tmp[opos - 1] != '/')
-						opos--;
-					tmp[opos] = 0;
-				}
-				newpath =
-					str_format
-					(
-						"%s/%s/%s",
-						tmp,
-						pointer,
-						path->str_text + ipos
-					);
-				str_free(path);
-				path = newpath;
-				ipos = 0;
-				opos = 0;
-				found = 0;
-				continue;
-			}
-		}
-#endif
-	
-		/*
-		 * keep the slash
-		 */
-		remember:
-		if (opos >= tmplen)
-		{
-			tmplen += 100;
-			tmp = mem_change_size(tmp, tmplen);
-		}
-		tmp[opos++] = c;
-	}
-	str_free(path);
-	assert(opos >= 1);
-	assert(tmp[0] == '/');
-	assert(tmp[opos - 1] == '/');
-	if (opos >= 2)
-		opos--;
-	path = str_n_from_c(tmp, opos);
-	trace_string(path->str_text);
-	trace((/*{*/"}\n"));
-	return path;
-}
-
-
 /*
  * NAME
  *	os_entryname - take path apart
@@ -910,49 +543,6 @@ os_entryname(path)
 }
 
 
-/*
- * NAME
- *	os_dirname - take path apart
- *
- * SYNOPSIS
- *	string_ty *os_dirname(string_ty *path);
- *
- * DESCRIPTION
- *	Os_dirname is used to extract the directory part
- *	of a pathname.
- *
- * RETURNS
- *	pointer to dynamically allocated string.
- *
- * CAVEAT
- *	Use str_free() when you are done with the value returned.
- */
-
-string_ty *
-os_dirname(path)
-	string_ty	*path;
-{
-	string_ty	*s;
-	char		*cp;
-
-	trace(("os_dirname(path = %08lX)\n{\n"/*}*/, path));
-	trace_string(path->str_text);
-	s = os_pathname(path, 1);
-	cp = strrchr(s->str_text, '/');
-	assert(cp);
-	if (cp > s->str_text)
-	{
-		path = str_n_from_c(s->str_text, cp - s->str_text);
-		str_free(s);
-	}
-	else
-		path = s;
-	trace_string(path->str_text);
-	trace((/*{*/"}\n"));
-	return path;
-}
-
-
 string_ty *
 os_below_dir(higher, lower)
 	string_ty	*higher;
@@ -1289,12 +879,46 @@ os_mtime_range(path, oldest_p, newest_p)
 }
 
 
+time_t
+os_mtime_actual(path)
+	string_ty	*path;
+{
+	struct stat	st;
+	int		oret;
+
+	trace(("os_mtime_actual(path = %08lX)\n{\n"/*}*/, path));
+	os_become_must_be_active();
+	trace_string(path->str_text);
+
+#ifdef S_IFLNK
+	oret = glue_lstat(path->str_text, &st);
+#else
+	oret = glue_stat(path->str_text, &st);
+#endif
+	if (oret)
+	{
+		sub_context_ty	*scp;
+
+		scp = sub_context_new();
+		sub_errno_set(scp);
+		sub_var_set(scp, "File_Name", "%S", path);
+		fatal_intl(scp, i18n("stat $filename: $errno"));
+		/* NOTREACHED */
+	}
+
+	trace(("return %ld;\n", (long)st.st_mtime));
+	trace((/*{*/"}\n"));
+	return st.st_mtime;
+}
+
+
 void
 os_mtime_set(path, when)
 	string_ty	*path;
 	time_t		when;
 {
 	struct utimbuf	utb;
+	int		err;
 
 	trace(("os_mtime_set(path = %08lX, when = %ld)\n{\n"/*}*/, path, when));
 	os_become_must_be_active();
@@ -1302,7 +926,12 @@ os_mtime_set(path, when)
 	trace(("when = %s", ctime(&when)));
 	utb.actime = when;
 	utb.modtime = when;
-	if (glue_utime(path->str_text, &utb))
+	err = glue_utime(path->str_text, &utb);
+#ifdef __CYGWIN__
+	if (err && errno == EACCES)
+		err = 0;
+#endif
+	if (err)
 	{
 		sub_context_ty	*scp;
 
@@ -1607,6 +1236,11 @@ os_become_init()
 	become_orig_umask = umask(DEFAULT_UMASK);
 	become_orig_uid = getuid();
 	become_orig_gid = getgid();
+#ifdef SINGLE_USER
+	become_testing = -1;
+	become_active_uid = become_orig_uid;
+	become_active_gid = become_orig_gid;
+#else
 	if (setuid(0))
 	{
 		become_testing = 1;
@@ -1615,6 +1249,7 @@ os_become_init()
 	}
 	else
 		setgid(0);
+#endif
 	become_inited = 1;
 }
 
@@ -2164,8 +1799,10 @@ pathconf_inner(path, arg)
 #else
 	/*
 	 * This system does not have the pathconf system call.
+	 * (Return EINVAL rather than ENOSYS, because the outer wrapper
+	 * expects EINVAL.)
 	 */
-	errno = ENOSYS;
+	errno = EINVAL;
 	return -1;
 #endif
 }
@@ -2353,36 +1990,6 @@ os_symlink_query(path)
 }
 
 
-void
-os_junkfile(path, mode)
-	string_ty	*path;
-	int		mode;
-{
-	os_become_must_be_active();
-	if (glue_junkfile(path->str_text))
-	{
-		sub_context_ty	*scp;
-
-		scp = sub_context_new();
-		sub_errno_set(scp);
-		sub_var_set(scp, "File_Name", "%S", path);
-		fatal_intl(scp, i18n("junkfile $filename: $errno"));
-		sub_context_delete(scp);
-	}
-	if (glue_chmod(path->str_text, mode))
-	{
-		sub_context_ty	*scp;
-
-		scp = sub_context_new();
-		sub_errno_set(scp);
-		sub_var_set(scp, "File_Name", "%S", path);
-		sub_var_set(scp, "Argument", "%5.5o", mode);
-		fatal_intl(scp, i18n("chmod(\"$filename\", $arg): $errno"));
-		/* NOTREACHED */
-	}
-}
-
-
 /*
  * NAME
  *	os_throttle
