@@ -1,6 +1,6 @@
 /*
  *	aegis - project change supervisor
- *	Copyright (C) 1991, 1992, 1993, 1994, 1995, 1996, 1997 Peter Miller;
+ *	Copyright (C) 1991, 1992, 1993, 1994, 1995, 1996, 1997, 1999 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -47,6 +47,7 @@ string_ty *os_path_cat _((string_ty *, string_ty *));
 string_ty *os_path_rel2abs _((string_ty *, string_ty *));
 string_ty *os_pathname _((string_ty *, int));
 string_ty *os_dirname _((string_ty *));
+string_ty *os_dirname_relative _((string_ty *));
 string_ty *os_entryname _((string_ty *));
 string_ty *os_below_dir _((string_ty *, string_ty *));
 void os_chdir _((string_ty *));
@@ -55,7 +56,9 @@ void os_setgid _((int));
 void os_execute _((string_ty *cmd, int flags, string_ty *dir));
 int os_execute_retcode _((string_ty *cmd, int flags, string_ty *dir));
 string_ty *os_execute_slurp _((string_ty *cmd, int flags, string_ty *dir));
+long os_file_size _((string_ty *));
 void os_mtime_range _((string_ty *, time_t *, time_t *));
+time_t os_mtime_actual _((string_ty *));
 void os_mtime_set _((string_ty *, time_t));
 void os_mtime_set_errok _((string_ty *, time_t));
 void os_chown_check _((string_ty *path, int mode, int uid, int gid));
@@ -104,7 +107,6 @@ int os_pathconf_path_max _((string_ty *));
 void os_symlink _((string_ty *, string_ty *));
 string_ty *os_readlink _((string_ty *));
 int os_symlink_query _((string_ty *));
-void os_junkfile _((string_ty *path, int mode));
 void os_throttle _((void));
 void os_owner_query _((string_ty *, int *, int *));
 string_ty *os_fingerprint _((string_ty *));
@@ -114,4 +116,7 @@ void os_interrupt_cope _((void));
 void os_interrupt_ignore _((void));
 int os_interrupt_has_occurred _((void));
 
+int os_isa_directory _((string_ty *));
+int os_isa_special_file _((string_ty *)); /* !S_IFREG */
+
 #endif /* OS_H */
