@@ -1,6 +1,6 @@
 /*
  *	aegis - project change supervisor
- *	Copyright (C) 1992, 1993, 1995, 1997 Peter Miller;
+ *	Copyright (C) 1992, 1993, 1995, 1997, 1999 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -23,7 +23,7 @@
 #ifndef PAGER_H
 #define PAGER_H
 
-#include <stdio.h>
+#include <ac/stdio.h>
 #include <main.h>
 
 void option_pager_set _((int, void(*)(void)));
