@@ -1,6 +1,6 @@
 /*
  *	aegis - project change supervisor
- *	Copyright (C) 1991, 1992, 1993, 1994 Peter Miller.
+ *	Copyright (C) 1991, 1992, 1993, 1994, 1999 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -38,6 +38,7 @@ struct sem_ty
 void sem_push _((type_ty *, void *));
 void sem_pop _((void));
 void sem_integer _((long));
+void sem_real _((double));
 void sem_string _((string_ty *));
 void sem_enum _((string_ty *));
 void sem_list _((void));
@@ -45,5 +46,7 @@ void sem_field _((string_ty *));
 
 void *parse _((char *, type_ty *));
 void *parse_env _((char *, type_ty *));
+struct input_ty; /* existence */
+void *parse_input _((struct input_ty *, type_ty *));
 
 #endif /* PARSE_H */
