@@ -1,6 +1,6 @@
 /*
  *	aegis - project change supervisor
- *	Copyright (C) 1991, 1992, 1993, 1994, 1995, 1996, 1997, 1998 Peter Miller;
+ *	Copyright (C) 1991, 1992, 1993, 1994, 1995, 1996, 1997, 1998, 1999 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -21,14 +21,14 @@
  */
 
 #include <ac/ctype.h>
-#include <stdio.h>
+#include <ac/stdio.h>
 #include <ac/string.h>
 #include <ac/stdlib.h>
 
 #include <arglex2.h>
 #include <change.h>
 #include <change_bran.h>
-#include <change_file.h>
+#include <change/file.h>
 #include <commit.h>
 #include <error.h>
 #include <fstrcmp.h>
@@ -40,6 +40,7 @@
 #include <project.h>
 #include <project_hist.h>
 #include <pstate.h>
+#include <skip_unlucky.h>
 #include <sub.h>
 #include <trace.h>
 #include <user.h>
@@ -384,6 +385,11 @@ convert_to_new_format(pp)
 		pstate_data->version_previous = 0;
 	}
 
+	/*
+	 * By default we reuse change numbers.
+	 */
+	change_branch_reuse_change_numbers_set(pp->pcp, 1);
+
 	/*
 	 * Phew!  Who would ever have guessed there was so much to do
 	 * when it came to converting a project to use branching?
@@ -767,12 +773,15 @@ project_bind_existing(pp)
 {
 	string_ty	*s;
 	string_ty	*parent_name;
+	int		alias_retry_count;
 
 	/*
 	 * make sure project exists
 	 */
 	trace(("project_bind_existing(pp = %08lX)\n{\n"/*}*/, pp));
 	assert(!pp->home_path);
+	alias_retry_count = 0;
+	alias_retry:
 	s = gonzo_project_home_path_from_name(pp->name);
 
 	/*
@@ -815,6 +824,32 @@ project_bind_existing(pp)
 		return;
 	}
 
+	/*
+	 * If the name was not found, try to find an alias match for it.
+	 * Loop if an alias is found.
+	 */
+	if (!s)
+	{
+		string_ty	*other;
+
+		other = gonzo_alias_to_actual(pp->name);
+		if (other)
+		{
+			if (++alias_retry_count > 5)
+			{
+				project_fatal
+				(
+					pp,
+					0,
+					i18n("alias loop detected")
+				);
+			}
+			str_free(pp->name);
+			pp->name = str_copy(other);
+			goto alias_retry;
+		}
+	}
+
 	/*
 	 * If the name was not found, try to find a fuzzy match for it.
 	 * In general, this results in more informative error messages.
@@ -1173,6 +1208,7 @@ project_pstate_write(pp)
 	string_ty	*filename_new;
 	string_ty	*filename_old;
 	static int	count;
+	int		compress;
 
 	trace(("project_pstate_write(pp)\n{\n"/*}*/, pp));
 
@@ -1185,6 +1221,7 @@ project_pstate_write(pp)
 	/*
 	 * write it out
 	 */
+	compress = project_compress_database_get(pp);
 	if (pp->pstate_data)
 	{
 		filename = project_pstate_path_get(pp);
@@ -1198,13 +1235,13 @@ project_pstate_write(pp)
 		if (pp->is_a_new_file)
 		{
 			undo_unlink_errok(filename_new);
-			pstate_write_file(filename_new->str_text, pp->pstate_data);
+			pstate_write_file(filename_new->str_text, pp->pstate_data, compress);
 			commit_rename(filename_new, filename);
 		}
 		else
 		{
 			undo_unlink_errok(filename_new);
-			pstate_write_file(filename_new->str_text, pp->pstate_data);
+			pstate_write_file(filename_new->str_text, pp->pstate_data, compress);
 			commit_rename(filename, filename_old);
 			commit_rename(filename_new, filename);
 			commit_unlink_errok(filename_old);
@@ -1876,12 +1913,17 @@ project_next_test_number_get(pp)
 {
 	pstate		pstate_data;
 	long		result;
+	int		skip;
 
 	trace(("project_next_test_number_get(pp = %08lX)\n{\n"/*}*/, pp));
+	skip = project_skip_unlucky_get(pp);
 	while (pp->parent)
 		pp = pp->parent;
 	pstate_data = project_pstate_get(pp);
-	result = pstate_data->next_test_number++;
+	result = pstate_data->next_test_number;
+	if (skip)
+		result = skip_unlucky(result);
+	pstate_data->next_test_number = result + 1;
 	trace(("return %ld;\n", result));
 	trace((/*{*/"}\n"));
 	return result;
@@ -1911,89 +1953,95 @@ project_minimum_change_number_set(pp, n)
 }
 
 
-void
-project_list_get(wlp)
-	string_list_ty		*wlp;
+int
+project_reuse_change_numbers_get(pp)
+	project_ty	*pp;
 {
-	size_t		j;
+	change_ty	*cp;
 
-	/*
-	 * get the top-level project list
-	 */
-	trace(("project_list_get()\n{\n"/*}*/));
-	gonzo_project_list(wlp);
+	cp = project_change_get(pp);
+	return change_branch_reuse_change_numbers_get(cp);
+}
 
-	/*
-	 * chase down each one, looking for branches
-	 *
-	 * This list will get longer as we search.  It is bounded by the
-	 * finite nature of the branch tree.
-	 */
-	for (j = 0; j < wlp->nstrings; ++j)
-	{
-		string_ty	*name;
-		project_ty	*pp;
-		int		err;
 
-		name = wlp->string[j];
-		trace(("name = \"%s\"\n", name->str_text));
-		pp = project_alloc(name);
-		project_bind_existing(pp);
+void
+project_reuse_change_numbers_set(pp, n)
+	project_ty	*pp;
+	int		n;
+{
+	change_ty	*cp;
 
-		/*
-		 * watch out for permissions
-		 * (returns errno of attempt to read project state)
-		 */
-		err = project_is_readable(pp);
+	cp = project_change_get(pp);
+	change_branch_reuse_change_numbers_set(cp, n);
+}
 
-		if (!err)
-		{
-			change_ty	*cp;
-			long		*lp;
-			size_t		len;
-			long		k;
 
-			/*
-			 * check each change
-			 * add it to the list if it is a branch
-			 */
-			trace(("readable\n"));
-			cp = project_change_get(pp);
-			change_branch_sub_branch_list_get(cp, &lp, &len);
-			for (k = 0; k < len; ++k)
-			{
-				long		cn;
-				change_ty	*cp2;
+long
+project_minimum_branch_number_get(pp)
+	project_ty	*pp;
+{
+	change_ty	*cp;
 
-				cn = lp[k];
-				trace(("cn = %ld\n", cn));
-				cp2 = change_alloc(pp, cn);
-				change_bind_existing(cp2);
-				/* active only */
-				if (change_is_a_branch(cp2))
-				{
-					string_ty	*s;
+	cp = project_change_get(pp);
+	return change_branch_minimum_branch_number_get(cp);
+}
 
-					/* punctuation (needs cp2) */
-					trace(("is a branch\n"));
-					s = str_format("%S.%ld", name, magic_zero_decode(cn));
-					string_list_append(wlp, s);
-					str_free(s);
-				}
-				change_free(cp2);
-			}
-			/* do NOT free ``lp'' */
-			/* do NOT free ``cp'' */
-		}
-		project_free(pp);
-	}
 
-	/*
-	 * sort the list of names
-	 * (C locale)
-	 */
-	string_list_sort(wlp);
-	trace((/*{*/"}\n"));
+void
+project_minimum_branch_number_set(pp, n)
+	project_ty	*pp;
+	long		n;
+{
+	change_ty	*cp;
+
+	cp = project_change_get(pp);
+	change_branch_minimum_branch_number_set(cp, n);
+}
+
+
+int
+project_skip_unlucky_get(pp)
+	project_ty	*pp;
+{
+	change_ty	*cp;
+
+	cp = project_change_get(pp);
+	return change_branch_skip_unlucky_get(cp);
+}
+
+
+void
+project_skip_unlucky_set(pp, n)
+	project_ty	*pp;
+	int		n;
+{
+	change_ty	*cp;
+
+	cp = project_change_get(pp);
+	change_branch_skip_unlucky_set(cp, n);
+}
+
+
+int
+project_compress_database_get(pp)
+	project_ty	*pp;
+{
+	change_ty	*cp;
+
+	cp = project_change_get(pp);
+	return change_branch_compress_database_get(cp);
+}
+
+
+void
+project_compress_database_set(pp, n)
+	project_ty	*pp;
+	int		n;
+{
+	change_ty	*cp;
+
+	cp = project_change_get(pp);
+	change_branch_compress_database_set(cp, n);
 }
 
 
