@@ -1,6 +1,6 @@
 /*
  *	aegis - project change supervisor
- *	Copyright (C) 1991, 1992, 1993, 1994, 1995, 1996, 1997, 1998 Peter Miller;
+ *	Copyright (C) 1991, 1992, 1993, 1994, 1995, 1996, 1997, 1998, 1999 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -21,7 +21,7 @@
  */
 
 #include <ac/ctype.h>
-#include <errno.h>
+#include <ac/errno.h>
 #include <ac/stdio.h>
 #include <ac/stddef.h>
 #include <ac/stdlib.h>
@@ -37,36 +37,50 @@
 #include <arglex.h>
 #include <change.h>
 #include <change_bran.h>
-#include <change_file.h>
-#include <column_width.h>
+#include <change/file.h>
 #include <error.h>
 #include <file.h>
 #include <gonzo.h>
 #include <language.h>
-#include <libdir.h>
 #include <mem.h>
 #include <option.h>
 #include <os.h>
 #include <progname.h>
 #include <project.h>
-#include <project_file.h>
+#include <project/file.h>
 #include <project_hist.h>
 #include <str_list.h>
 #include <sub.h>
+#include <sub/addpathsuffi.h>
 #include <sub/basename.h>
+#include <sub/binary_direc.h>
+#include <sub/capitalize.h>
 #include <sub/comment.h>
+#include <sub/data_directo.h>
+#include <sub/dirname.h>
+#include <sub/dirname_rel.h>
 #include <sub/dollar.h>
+#include <sub/downcase.h>
 #include <sub/expr.h>
 #include <sub/left.h>
 #include <sub/length.h>
+#include <sub/librar_direc.h>
 #include <sub/namemax.h>
+#include <sub/project.h>
+#include <sub/project/adminis_list.h>
+#include <sub/project/baseline.h>
+#include <sub/project/develop_list.h>
+#include <sub/project/integra_list.h>
+#include <sub/project/reviewe_list.h>
 #include <sub/quote.h>
 #include <sub/right.h>
+#include <sub/substitute.h>
 #include <sub/trim_directo.h>
 #include <sub/trim_extensi.h>
+#include <sub/upcase.h>
+#include <sub/user.h>
 #include <sub/zero_pad.h>
 #include <trace.h>
-#include <user.h>
 #include <wstr_list.h>
 
 
@@ -91,9 +105,9 @@ struct sub_context_ty
 	size_t		sub_var_pos;
 	struct change_ty *cp;
 	struct project_ty *pp;
-	char		*suberr;
+	const char	*suberr;
 	int		errno_sequester;
-	char		*file_name;
+	const char	*file_name;
 	int		line_number;
 };
 
@@ -103,7 +117,7 @@ typedef wstring_ty *(*fp)_((sub_context_ty *, wstring_list_ty *));
 typedef struct sub_table_ty sub_table_ty;
 struct sub_table_ty
 {
-	char		*name;
+	const char	*name;
 	fp		func;
 	int		resubstitute;
 	wstring_ty	*value;
@@ -159,7 +173,7 @@ collect_destructor(cp)
 
 sub_context_ty *
 sub_context_New(file_name, line_number)
-	char		*file_name;
+	const char	*file_name;
 	int		line_number;
 {
 	sub_context_ty	*p;
@@ -199,129 +213,17 @@ sub_context_delete(p)
 void
 sub_context_error_set(scp, s)
 	sub_context_ty	*scp;
-	char		*s;
+	const char	*s;
 {
 	scp->suberr = s;
 }
 
 
-/*
- * NAME
- *	sub_administrator_list - the administrator_list substitution
- *
- * SYNOPSIS
- *	wstring_ty *sub_administrator_list(wstring_list_ty *arg);
- *
- * DESCRIPTION
- *	The sub_administrator_list function implements the administrator_list
- * 	substitution.  The administrator_list substitution is replaced by
- *	a space separated list of project administrators.
- *
- * ARGUMENTS
- *	arg	- list of arguments, including the function name as [0]
- *
- * RETURNS
- *	a pointer to a string in dynamic memory;
- *	or NULL on error, setting suberr appropriately.
- */
-
-static wstring_ty *sub_administrator_list _((sub_context_ty *,
-	wstring_list_ty *));
-
-static wstring_ty *
-sub_administrator_list(scp, arg)
+project_ty *
+sub_context_project_get(scp)
 	sub_context_ty	*scp;
-	wstring_list_ty	*arg;
 {
-	wstring_ty	*result;
-	pstate		pstate_data;
-	long		j;
-
-	trace(("sub_administrator_list()\n{\n"/*}*/));
-	if (arg->nitems != 1)
-	{
-		scp->suberr = i18n("requires zero arguments");
-		result = 0;
-	}
-	else if (!scp->pp)
-	{
-		scp->suberr = i18n("not valid in current context");
-		result = 0;
-	}
-	else
-	{
-		string_list_ty		wl;
-		string_ty	*s;
-
-		/*
-		 * build a string containing all of the project administrators
-		 */
-		pstate_data = project_pstate_get(scp->pp);
-		string_list_constructor(&wl);
-		for (j = 0; ; ++j)
-		{
-			s = project_administrator_nth(scp->pp, j);
-			if (!s)
-				break;
-			string_list_append(&wl, s);
-		}
-		s = wl2str(&wl, 0, wl.nstrings, " ");
-		trace(("s = \"%s\"\n", s->str_text));
-		string_list_destructor(&wl);
-		result = str_to_wstr(s);
-		str_free(s);
-	}
-	trace(("return %8.8lX;\n", (long)result));
-	trace((/*{*/"}\n"));
-	return result;
-}
-
-
-/*
- * NAME
- *	sub_baseline - the baseline substitution
- *
- * SYNOPSIS
- *	wstring_ty *sub_baseline(wstring_list_ty *arg);
- *
- * DESCRIPTION
- *	The sub_baseline function implements the baseline substitution.
- *	The baseline substitution is used to insert the absolute path
- *	of the baseline.
- *
- * ARGUMENTS
- *	arg	- list of arguments, including the function name as [0]
- *
- * RETURNS
- *	a pointer to a string in dynamic memory;
- *	or NULL on error, setting suberr appropriately.
- */
-
-static wstring_ty *sub_baseline _((sub_context_ty *, wstring_list_ty *));
-
-static wstring_ty *
-sub_baseline(scp, arg)
-	sub_context_ty	*scp;
-	wstring_list_ty	*arg;
-{
-	wstring_ty	*result;
-
-	trace(("sub_baseline()\n{\n"/*}*/));
-	if (arg->nitems != 1)
-	{
-		scp->suberr = i18n("requires zero arguments");
-		result = 0;
-	}
-	else if (!scp->pp)
-	{
-		scp->suberr = i18n("not valid in current context");
-		result = 0;
-	}
-	else
-		result = str_to_wstr(project_baseline_path_get(scp->pp, 0));
-	trace(("return %8.8lX;\n", (long)result));
-	trace((/*{*/"}\n"));
-	return result;
+	return scp->pp;
 }
 
 
@@ -674,74 +576,6 @@ sub_developer(scp, arg)
 }
 
 
-/*
- * NAME
- *	sub_developer_list - the developer_list substitution
- *
- * SYNOPSIS
- *	wstring_ty *sub_developer_list(wstring_list_ty *arg);
- *
- * DESCRIPTION
- *	The sub_developer_list function implements the developer_list
- *	substitution.  The developer_list substitution is replaced by a
- *	space separated list of the project's developers.
- *
- * ARGUMENTS
- *	arg	- list of arguments, including the function name as [0]
- *
- * RETURNS
- *	a pointer to a string in dynamic memory;
- *	or NULL on error, setting suberr appropriately.
- */
-
-static wstring_ty *sub_developer_list _((sub_context_ty *, wstring_list_ty *));
-
-static wstring_ty *
-sub_developer_list(scp, arg)
-	sub_context_ty	*scp;
-	wstring_list_ty	*arg;
-{
-	wstring_ty	*result;
-	long		j;
-	string_list_ty		wl;
-	string_ty	*s;
-
-	trace(("sub_developer_list()\n{\n"/*}*/));
-	if (arg->nitems != 1)
-	{
-		scp->suberr = i18n("requires zero arguments");
-		result = 0;
-	}
-	else if (!scp->pp)
-	{
-		scp->suberr = i18n("not valid in current context");
-		result = 0;
-	}
-	else
-	{
-		/*
-		 * build a string containing all of the project developers
-		 */
-		assert(scp->pp);
-		string_list_constructor(&wl);
-		for (j = 0; ; ++j)
-		{
-			s = project_developer_nth(scp->pp, j);
-			if (!s)
-				break;
-			string_list_append(&wl, s);
-		}
-		s = wl2str(&wl, 0, wl.nstrings, " ");
-		string_list_destructor(&wl);
-		result = str_to_wstr(s);
-		str_free(s);
-	}
-	trace(("return %8.8lX;\n", (long)result));
-	trace((/*{*/"}\n"));
-	return result;
-}
-
-
 /*
  * NAME
  *	sub_development_directory - the development_directory substitution
@@ -808,60 +642,6 @@ sub_development_directory(scp, arg)
 }
 
 
-/*
- * NAME
- *	sub_dirname - the dirname substitution
- *
- * SYNOPSIS
- *	wstring_ty *sub_dirname(wstring_list_ty *arg);
- *
- * DESCRIPTION
- *	The sub_dirname function implements the dirname substitution.
- *	The dirname substitution is replaced by the dirname of
- *	the argument path, similar to the dirname(1) command.
- *
- * ARGUMENTS
- *	arg	- list of arguments, including the function name as [0]
- *
- * RETURNS
- *	a pointer to a string in dynamic memory;
- *	or NULL on error, setting suberr appropriately.
- */
-
-static wstring_ty *sub_dirname _((sub_context_ty *, wstring_list_ty *));
-
-static wstring_ty *
-sub_dirname(scp, arg)
-	sub_context_ty	*scp;
-	wstring_list_ty	*arg;
-{
-	wstring_ty	*result;
-
-	trace(("sub_dirname()\n{\n"/*}*/));
-	if (arg->nitems != 2)
-	{
-		scp->suberr = i18n("requires one argument");
-		result = 0;
-	}
-	else
-	{
-		string_ty	*s1;
-		string_ty	*s2;
-
-		s1 = wstr_to_str(arg->item[1]);
-		os_become_orig();
-		s2 = os_dirname(s1);
-		os_become_undo();
-		str_free(s1);
-		result = str_to_wstr(s2);
-		str_free(s2);
-	}
-	trace(("return %8.8lX;\n", (long)result));
-	trace((/*{*/"}\n"));
-	return result;
-}
-
-
 /*
  * NAME
  *	sub_errno - the errno substitution
@@ -954,51 +734,6 @@ sub_errno(scp, arg)
 }
 
 
-/*
- * NAME
- *	sub_downcase - the downcase substitution
- *
- * SYNOPSIS
- *	wstring_ty *sub_downcase(wstring_list_ty *arg);
- *
- * DESCRIPTION
- *	The sub_downcase function implements the downcase substitution.
- *	The downcase substitution is replaced by the single argument
- *	mapped to lower case.
- *
- *	Requires exactly one argument.
- *
- * ARGUMENTS
- *	arg	- list of arguments, including the function name as [0]
- *
- * RETURNS
- *	a pointer to a string in dynamic memory;
- *	or NULL on error, setting suberr appropriately.
- */
-
-static wstring_ty *sub_downcase _((sub_context_ty *, wstring_list_ty *arg));
-
-static wstring_ty *
-sub_downcase(scp, arg)
-	sub_context_ty	*scp;
-	wstring_list_ty	*arg;
-{
-	wstring_ty	*result;
-
-	trace(("sub_downcase()\n{\n"/*}*/));
-	if (arg->nitems != 2)
-	{
-		scp->suberr = i18n("requires one argument");
-		result = 0;
-	}
-	else
-		result = wstr_to_lower(arg->item[1]);
-	trace(("return %8.8lX;\n", (long)result));
-	trace((/*{*/"}\n"));
-	return result;
-}
-
-
 /*
  * NAME
  *	sub_identifier - the identifier substitution
@@ -1161,116 +896,6 @@ sub_integrator(scp, arg)
 }
 
 
-/*
- * NAME
- *	sub_integrator_list - the integrator_list substitution
- *
- * SYNOPSIS
- *	string_ty *sub_integrator_list(wstring_list_ty *arg);
- *
- * DESCRIPTION
- *	The sub_integrator_list function implements the integrator_list
- *	substitution.  The integrator_list substitution is replaced by
- *	a space separated list of the project's integrators.
- *
- * ARGUMENTS
- *	arg	- list of arguments, including the function name as [0]
- *
- * RETURNS
- *	a pointer to a string in dynamic memory;
- *	or NULL on error, setting suberr appropriately.
- */
-
-static wstring_ty *sub_integrator_list _((sub_context_ty *, wstring_list_ty *));
-
-static wstring_ty *
-sub_integrator_list(scp, arg)
-	sub_context_ty	*scp;
-	wstring_list_ty	*arg;
-{
-	wstring_ty	*result;
-	long		j;
-	string_list_ty		wl;
-	string_ty	*s;
-
-	trace(("sub_integrator_list()\n{\n"/*}*/));
-	if (arg->nitems != 1)
-	{
-		scp->suberr = i18n("requires zero arguments");
-		result = 0;
-	}
-	else if (!scp->pp)
-	{
-		scp->suberr = i18n("not valid in current context");
-		result = 0;
-	}
-	else
-	{
-		/*
-		 * build a string containing all of the project integrators
-		 */
-		string_list_constructor(&wl);
-		for (j = 0; ; ++j)
-		{
-			s = project_integrator_nth(scp->pp, j);
-			if (!s)
-				break;
-			string_list_append(&wl, s);
-		}
-		s = wl2str(&wl, 0, wl.nstrings, " ");
-		string_list_destructor(&wl);
-		result = str_to_wstr(s);
-		str_free(s);
-	}
-	trace(("return %8.8lX;\n", (long)result));
-	trace((/*{*/"}\n"));
-	return result;
-}
-
-
-/*
- * NAME
- *	sub_library - the library substitution
- *
- * SYNOPSIS
- *	string_ty *sub_library(wstring_list_ty *arg);
- *
- * DESCRIPTION
- *	The sub_library function implements the library substitution.
- *	The library substitution is replaced by the absolute path of
- *	aegis' library directory.
- *
- * ARGUMENTS
- *	arg	- list of arguments, including the function name as [0]
- *
- * RETURNS
- *	a pointer to a string in dynamic memory;
- *	or NULL on error, setting suberr appropriately.
- */
-
-static wstring_ty *sub_library _((sub_context_ty *, wstring_list_ty *));
-
-static wstring_ty *
-sub_library(scp, arg)
-	sub_context_ty	*scp;
-	wstring_list_ty	*arg;
-{
-	wstring_ty	*result;
-
-	trace(("sub_library()\n{\n"/*}*/));
-	if (arg->nitems != 1)
-	{
-		scp->suberr = i18n("requires zero arguments");
-		result = 0;
-	}
-	else
-		result = wstr_from_c(configured_datadir());
-	trace(("return %8.8lX;\n", (long)result));
-	trace((/*{*/"}\n"));
-	return result;
-}
-
-
 static wstring_ty *sub_plural _((sub_context_ty *, wstring_list_ty *));
 
 static wstring_ty *
@@ -1310,53 +935,6 @@ sub_plural(scp, arg)
 }
 
 
-/*
- * NAME
- *	sub_project - the project substitution
- *
- * SYNOPSIS
- *	string_ty *sub_project(wstring_list_ty *arg);
- *
- * DESCRIPTION
- *	The sub_project function implements the project substitution.
- *	The project substitution is replaced by the project name.
- *
- * ARGUMENTS
- *	arg	- list of arguments, including the function name as [0]
- *
- * RETURNS
- *	a pointer to a string in dynamic memory;
- *	or NULL on error, setting suberr appropriately.
- */
-
-static wstring_ty *sub_project _((sub_context_ty *, wstring_list_ty *));
-
-static wstring_ty *
-sub_project(scp, arg)
-	sub_context_ty	*scp;
-	wstring_list_ty	*arg;
-{
-	wstring_ty	*result;
-
-	trace(("sub_project()\n{\n"/*}*/));
-	if (arg->nitems != 1)
-	{
-		scp->suberr = i18n("requires zero arguments");
-		result = 0;
-	}
-	else if (!scp->pp)
-	{
-		scp->suberr = i18n("not valid in current context");
-		result = 0;
-	}
-	else
-		result = str_to_wstr(project_name_get(scp->pp));
-	trace(("return %8.8lX;\n", (long)result));
-	trace((/*{*/"}\n"));
-	return result;
-}
-
-
 /*
  * NAME
  *	sub_read_file - the read_file substitution
@@ -1475,73 +1053,6 @@ sub_reviewer(scp, arg)
 }
 
 
-/*
- * NAME
- *	sub_reviewer_list - the reviewer_list substitution
- *
- * SYNOPSIS
- *	string_ty *sub_reviewer_list(wstring_list_ty *arg);
- *
- * DESCRIPTION
- *	The sub_reviewer_list function implements the reviewer_list
- *	substitution.  The reviewer_list substitution is replaced by a
- *	space separated list of the project's reviewers.
- *
- * ARGUMENTS
- *	arg	- list of arguments, including the function name as [0]
- *
- * RETURNS
- *	a pointer to a string in dynamic memory;
- *	or NULL on error, setting suberr appropriately.
- */
-
-static wstring_ty *sub_reviewer_list _((sub_context_ty *, wstring_list_ty *));
-
-static wstring_ty *
-sub_reviewer_list(scp, arg)
-	sub_context_ty	*scp;
-	wstring_list_ty	*arg;
-{
-	wstring_ty	*result;
-	long		j;
-	string_list_ty		wl;
-	string_ty	*s;
-
-	trace(("sub_reviewer_list()\n{\n"/*}*/));
-	if (arg->nitems != 1)
-	{
-		scp->suberr = i18n("requires zero arguments");
-		result = 0;
-	}
-	else if (!scp->pp)
-	{
-		scp->suberr = i18n("not valid in current context");
-		result = 0;
-	}
-	else
-	{
-		/*
-		 * build a string containing all of the project reviewers
-		 */
-		string_list_constructor(&wl);
-		for (j = 0; ; ++j)
-		{
-			s = project_reviewer_nth(scp->pp, j);
-			if (!s)
-				break;
-			string_list_append(&wl, s);
-		}
-		s = wl2str(&wl, 0, wl.nstrings, " ");
-		string_list_destructor(&wl);
-		result = str_to_wstr(s);
-		str_free(s);
-	}
-	trace(("return %8.8lX;\n", (long)result));
-	trace((/*{*/"}\n"));
-	return result;
-}
-
-
 /*
  * NAME
  *	sub_search_path - the search_path substitution
@@ -1888,99 +1399,6 @@ sub_architecture(scp, arg)
 }
 
 
-/*
- * NAME
- *	sub_upcase - the upcase substitution
- *
- * SYNOPSIS
- *	string_ty *sub_upcase(wstring_list_ty *arg);
- *
- * DESCRIPTION
- *	The sub_upcase function implements the upcase substitution.
- *	The upcase substitution is replaced by the single argument
- *	mapped to upper case.
- *
- *	Requires exactly one argument.
- *
- * ARGUMENTS
- *	arg	- list of arguments, including the function name as [0]
- *
- * RETURNS
- *	a pointer to a string in dynamic memory;
- *	or NULL on error, setting suberr appropriately.
- */
-
-static wstring_ty *sub_upcase _((sub_context_ty *, wstring_list_ty *arg));
-
-static wstring_ty *
-sub_upcase(scp, arg)
-	sub_context_ty	*scp;
-	wstring_list_ty	*arg;
-{
-	wstring_ty	*result;
-
-	trace(("sub_upcase()\n{\n"/*}*/));
-	if (arg->nitems != 2)
-	{
-		scp->suberr = i18n("requires one argument");
-		result = 0;
-	}
-	else
-		result = wstr_to_upper(arg->item[1]);
-	trace(("return %8.8lX;\n", (long)result));
-	trace((/*{*/"}\n"));
-	return result;
-}
-
-
-/*
- * NAME
- *	sub_user - the user substitution
- *
- * SYNOPSIS
- *	string_ty *sub_user(wstring_list_ty *arg);
- *
- * DESCRIPTION
- *	The sub_user function implements the user substitution.
- *	The user substitution is replaced by the login name of the user
- *	who executed the current command.
- *
- * ARGUMENTS
- *	arg	- list of arguments, including the function name as [0]
- *
- * RETURNS
- *	a pointer to a string in dynamic memory;
- *	or NULL on error, setting suberr appropriately.
- */
-
-static wstring_ty *sub_user _((sub_context_ty *, wstring_list_ty *arg));
-
-static wstring_ty *
-sub_user(scp, arg)
-	sub_context_ty	*scp;
-	wstring_list_ty	*arg;
-{
-	wstring_ty	*result;
-	user_ty		*up;
-
-	trace(("sub_user()\n{\n"/*}*/));
-	if (arg->nitems != 1)
-	{
-		scp->suberr = i18n("requires zero arguments");
-		result = 0;
-	}
-	else
-	{
-		up = user_executing((project_ty *)0);
-		result = str_to_wstr(user_name(up));
-		user_free(up);
-	}
-	trace(("return %8.8lX;\n", (long)result));
-	trace((/*{*/"}\n"));
-	return result;
-}
-
-
 /*
  * NAME
  *	sub_version - the version substitution
@@ -2045,13 +1463,17 @@ static sub_table_ty table[] =
 {
 	{ "$",				sub_dollar,			},
 	{ "#",				sub_comment,			},
+	{ "Add_Path_Suffix",		sub_add_path_suffix,		},
 	{ "Administrator_List",		sub_administrator_list,		},
 	{ "ARCHitecture",		sub_architecture,		},
 	{ "BaseLine",			sub_baseline,			},
 	{ "Basename",			sub_basename,			},
+	{ "BINary_DIRectory",		sub_binary_directory,		},
+	{ "CAPitalize",			sub_capitalize,			},
 	{ "Change",			sub_change,			},
 	{ "Copyright_Years",		sub_copyright_years,		},
 	{ "COMment",			sub_comment,			},
+	{ "DATa_DIRectory",		sub_data_directory,		},
 	{ "DAte",			sub_date,			},
 	{ "DELta",			sub_delta,			},
 	{ "DEVeloper",			sub_developer,			},
@@ -2059,6 +1481,7 @@ static sub_table_ty table[] =
 	/* Default_Development_Directory				*/
 	{ "Development_Directory",	sub_development_directory,	},
 	{ "Dirname",			sub_dirname,			},
+	{ "Dirname_RELative",		sub_dirname_relative,		},
 	{ "DownCase",			sub_downcase,			},
 	{ "DOLlar",			sub_dollar,			},
 	/* Edit								*/
@@ -2076,7 +1499,8 @@ static sub_table_ty table[] =
 	{ "INTegrator_List",		sub_integrator_list,		},
 	{ "LEFt",			sub_left,			},
 	{ "LENgth",			sub_length,			},
-	{ "LIBrary",			sub_library,			},
+	{ "LIBrary",			sub_data_directory,		},
+	{ "LIBrary_DIRectory",		sub_library_directory,		},
 	/* MAgic							*/
 	/* MeSsaGe							*/
 	/* Most_Recent							*/
@@ -2095,6 +1519,7 @@ static sub_table_ty table[] =
 	{ "SHell",			sub_shell,			},
 	{ "Source",			sub_source,			},
 	{ "STate",			sub_state,			},
+	{ "SUBSTitute",			sub_substitute,			},
 	{ "Trim_DIRectory",		sub_trim_directory,		},
 	{ "Trim_EXTension",		sub_trim_extension,		},
 	{ "UName", /* undocumented */	sub_architecture,		},
@@ -2230,6 +1655,8 @@ execute(scp, arg)
 		tp = &scp->sub_var_list[j];
 		if (arglex_compare(tp->name, cmd->str_text))
 		{
+			if (tp->override)
+				goto override;
 			if (nhits < SIZEOF(hit))
 				hit[nhits++] = tp;
 		}
@@ -2317,7 +1744,7 @@ execute(scp, arg)
 		wstring_ty	*s2;
 		string_ty	*s3;
 		sub_context_ty	*inner;
-		char		*the_error;
+		const char	*the_error;
 
 		assert(scp->suberr);
 		s2 = wstring_list_to_wstring(arg, 0, arg->nitems, (char *)0);
@@ -3182,12 +2609,12 @@ in substitution \"$message\" found unused variables")
 }
 
 
-static wstring_ty *subst_intl_wide _((sub_context_ty *, char *));
+static wstring_ty *subst_intl_wide _((sub_context_ty *, const char *));
 
 static wstring_ty *
 subst_intl_wide(scp, msg)
 	sub_context_ty	*scp;
-	char		*msg;
+	const char	*msg;
 {
 	char		*tmp;
 	wstring_ty	*s;
@@ -3197,7 +2624,7 @@ subst_intl_wide(scp, msg)
 	language_human();
 	tmp = gettext(msg);
 	language_C();
-#ifdef DEBUG
+#if 0
 #ifdef HAVE_GETTEXT
 	if (tmp == msg)
 	{
@@ -3223,7 +2650,7 @@ subst_intl_wide(scp, msg)
 string_ty *
 subst_intl(scp, s)
 	sub_context_ty	*scp;
-	char		*s;
+	const char	*s;
 {
 	wstring_ty	*result_wide;
 	string_ty	*result;
@@ -3352,8 +2779,8 @@ sub_var_clear(scp)
 void
 sub_var_set(scp, name, fmt sva_last)
 	sub_context_ty	*scp;
-	char		*name;
-	char		*fmt;
+	const char	*name;
+	const char	*fmt;
 	sva_last_decl
 {
 	va_list		ap;
@@ -3386,7 +2813,7 @@ sub_var_set(scp, name, fmt sva_last)
 void
 sub_var_resubstitute(scp, name)
 	sub_context_ty	*scp;
-	char	*name;
+	const char	*name;
 {
 	sub_table_ty	*the_end;
 	sub_table_ty	*svp;
@@ -3405,7 +2832,7 @@ sub_var_resubstitute(scp, name)
 void
 sub_var_override(scp, name)
 	sub_context_ty	*scp;
-	char		*name;
+	const char	*name;
 {
 	sub_table_ty	*the_end;
 	sub_table_ty	*svp;
@@ -3424,7 +2851,7 @@ sub_var_override(scp, name)
 void
 sub_var_optional(scp, name)
 	sub_context_ty	*scp;
-	char		*name;
+	const char	*name;
 {
 	sub_table_ty	*the_end;
 	sub_table_ty	*svp;
@@ -3443,7 +2870,7 @@ sub_var_optional(scp, name)
 void
 sub_var_append_if_unused(scp, name)
 	sub_context_ty	*scp;
-	char		*name;
+	const char	*name;
 {
 	sub_table_ty	*the_end;
 	sub_table_ty	*svp;
@@ -3519,7 +2946,7 @@ wrap(s)
 		wstring_ty	*ws;
 
 		ws = wstr_from_c(progname);
-		progname_width = wcs_column_width(ws->wstr_text);
+		progname_width = wstr_column_width(ws);
 		wstr_free(ws);
 	}
 
@@ -3574,7 +3001,7 @@ wrap(s)
 				c = '?';
 			nbytes = wctomb(dummy, c);
 
-			cw = column_width(c);
+			cw = wcwidth(c);
 			if (nbytes <= 0)
 			{
 				/*
@@ -3766,7 +3193,7 @@ wrap(s)
 void
 error_intl(scp, s)
 	sub_context_ty	*scp;
-	char		*s;
+	const char	*s;
 {
 	wstring_ty	*message;
 	int		need_to_delete;
@@ -3791,10 +3218,10 @@ error_intl(scp, s)
 void
 fatal_intl(scp, s)
 	sub_context_ty	*scp;
-	char		*s;
+	const char	*s;
 {
 	wstring_ty	*message;
-	static	char	*double_jeopardy;
+	static const char *double_jeopardy;
 	int		need_to_delete;
 
 	if (!scp)
@@ -3840,7 +3267,7 @@ This is a probably bug.",
 void
 verbose_intl(scp, s)
 	sub_context_ty	*scp;
-	char		*s;
+	const char	*s;
 {
 	wstring_ty	*message;
 	int		need_to_delete;
