@@ -1,7 +1,7 @@
 #!/bin/sh
 #
 #	aegis - project change supervisor
-#	Copyright (C) 1991, 1992, 1993, 1994, 1995 Peter Miller;
+#	Copyright (C) 1991, 1992, 1993, 1994, 1995, 1996, 1997, 1998 Peter Miller;
 #	All rights reserved.
 #
 #	This program is free software; you can redistribute it and/or modify
@@ -16,11 +16,11 @@
 #
 #	You should have received a copy of the GNU General Public License
 #	along with this program; if not, write to the Free Software
-#	Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+#	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
 #
 # MANIFEST: test for correct behaviour around symbolic links
 #
-# Make sure can cope with symbolic links.
+# Make sure aede and aeipass can cope with symbolic links.
 # This test will always pass on systems without symbolic links.
 #
 
@@ -28,6 +28,8 @@ unset AEGIS_PROJECT
 unset AEGIS_CHANGE
 unset AEGIS_PATH
 unset AEGIS
+unset LINES
+unset COLS
 umask 022
 
 USER=${USER:-${LOGNAME:-`whoami`}}
@@ -36,7 +38,11 @@ PAGER=cat
 export PAGER
 
 AEGIS_FLAGS="delete_file_preference = no_keep; \
-	diff_preference = automatic_merge;"
+	lock_wait_preference = always; \
+	diff_preference = automatic_merge; \
+	pager_preference = never; \
+	persevere_preference = all; \
+	log_file_preference = never;"
 export AEGIS_FLAGS
 AEGIS_THROTTLE=2
 export AEGIS_THROTTLE
@@ -44,14 +50,23 @@ export AEGIS_THROTTLE
 work=${AEGIS_TMP:-/tmp}/$$
 
 here=`pwd`
-if test $? -ne 0 ; then exit 1; fi
+if test $? -ne 0 ; then exit 2; fi
 
 if test "$1" != "" ; then bin="$here/$1/bin"; else bin="$here/bin"; fi
 
+no_result()
+{
+	set +x
+	echo "NO RESULT for  test for correct behaviour around symbolic links ($activity)" 1>&2
+	cd $here
+	find $work -type d -user $USER -exec chmod u+w {} \;
+	rm -rf $work
+	exit 2
+}
 fail()
 {
 	set +x
-	echo FAILED test for correct behaviour around symbolic links 1>&2
+	echo "FAILED test for correct behaviour around symbolic links ($activity)" 1>&2
 	cd $here
 	find $work -type d -user $USER -exec chmod u+w {} \;
 	rm -rf $work
@@ -66,16 +81,47 @@ pass()
 	rm -rf $work
 	exit 0
 }
-trap "fail" 1 2 3 15
+trap "no_result" 1 2 3 15
 
-mkdir $work
-if test $? -ne 0 ; then fail; fi
+activity="working directory 71"
+mkdir $work $work/lib
+if test $? -ne 0 ; then no_result; fi
+chmod 777 $work/lib
+if test $? -ne 0 ; then no_result; fi
 cd $work
-if test $? -ne 0 ; then fail; fi
+if test $? -ne 0 ; then no_result; fi
+
+#
+# use the built-in error messages
+#
+AEGIS_MESSAGE_LIBRARY=$work/no-such-dir
+export AEGIS_MESSAGE_LIBRARY
+unset LANG
+unset LANGUAGE
+
+#
+# If the C compiler is called something other than ``cc'', as discovered
+# by the configure script, create a shell script called ``cc'' which
+# invokes the correct C compiler.  Make sure the current directory is in
+# the path, so that it will be invoked.
+#
+if test "$CC" != "" -a "$CC" != "cc"
+then
+	cat >> cc << fubar
+#!/bin/sh
+exec $CC \$*
+fubar
+	if test $? -ne 0 ; then no_result; fi
+	chmod a+rx cc
+	if test $? -ne 0 ; then no_result; fi
+	PATH=${work}:${PATH}
+	export PATH
+fi
 
 #
 # program to ask questions about symlinks
 #
+activity="symlink test program 104"
 cat > symlink.c << 'fubar'
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -99,9 +145,9 @@ main(argc, argv)
 #endif
 }
 fubar
-if test $? -ne 0 ; then fail; fi
+if test $? -ne 0 ; then no_result; fi
 cc -o symlink symlink.c
-if test $? -ne 0 ; then fail; fi
+if test $? -ne 0 ; then no_result; fi
 
 #
 # if this system has no symlinks
@@ -124,61 +170,69 @@ symlinkdest=$workchan/symlinkdest
 # make a new project
 #	and check files it should have made
 #
-$bin/aegis -newpro foo -dir $workproj -lib $worklib
-if test $? -ne 0 ; then fail; fi
+activity="new project 153"
+$bin/aegis -newpro foo -version "" -dir $workproj -lib $worklib
+if test $? -ne 0 ; then no_result; fi
 
 #
 # change project attributes
 #
+activity="project attributes 160"
 cat > $tmp << 'end'
 description = "A bogus project created to test things.";
 developer_may_review = true;
 developer_may_integrate = true;
 reviewer_may_integrate = true;
 end
+if test $? -ne 0 ; then no_result; fi
 $bin/aegis -proatt -f $tmp -proj foo -lib $worklib
-if test $? -ne 0 ; then fail; fi
+if test $? -ne 0 ; then no_result; fi
 
 #
 # create a new change
 #	make sure it creates the files it should
 #
+activity="new change 174"
 cat > $tmp << 'end'
 brief_description = "This change is used to test the aegis functionality \
 with respect to change descriptions.";
 cause = internal_bug;
 end
-$bin/aegis -new_change -f $tmp -project foo -lib $worklib
-if test $? -ne 0 ; then fail; fi
+$bin/aegis -new_change 1 -f $tmp -project foo -lib $worklib
+if test $? -ne 0 ; then no_result; fi
 
 #
 # add a new developer
 #
+activity="new developer 186"
 $bin/aegis -newdev $USER -p foo -lib $worklib
-if test $? -ne 0 ; then fail; fi
+if test $? -ne 0 ; then no_result; fi
 
 #
 # begin development of a change
 #	check it made the files it should
 #
+activity="develop begin 194"
 $bin/aegis -devbeg 1 -p foo -dir $workchan -lib $worklib
-if test $? -ne 0 ; then fail; fi
+if test $? -ne 0 ; then no_result; fi
 
 #
 # create a symbolic link in the development directory
 #
+activity="create a symlink 201"
 mkdir $symlinkdest
-if test $? -ne 0 ; then fail; fi
+if test $? -ne 0 ; then no_result; fi
 ln -s $symlinkdest $symlinktestfile
-if test $? -ne 0 ; then fail; fi
+if test $? -ne 0 ; then no_result; fi
 
 #
 # add a new files to the change
 #
+activity="new file 210"
 $bin/aegis -new_file $workchan/main.c -nl -lib $worklib -p foo
-if test $? -ne 0 ; then fail; fi
+if test $? -ne 0 ; then no_result; fi
 $bin/aegis -new_file $workchan/config -nl -lib $worklib -p foo
-if test $? -ne 0 ; then fail; fi
+if test $? -ne 0 ; then no_result; fi
 cat > $workchan/main.c << 'end'
 void
 main()
@@ -186,6 +240,7 @@ main()
 	exit(0);
 }
 end
+if test $? -ne 0 ; then no_result; fi
 cat > $workchan/config << 'end'
 build_command = "rm -f foo; cc -o foo -D'VERSION=\"$v\"' main.c";
 link_integration_directory = true;
@@ -204,14 +259,21 @@ diff_command = "set +e; diff $orig $i > $out; test $$? -le 1";
 diff3_command = "(diff3 -e $mr $orig $i | sed -e '/^w$$/d' -e '/^q$$/d'; \
 	echo '1,$$p' ) | ed - $mr > $out";
 end
+if test $? -ne 0 ; then no_result; fi
 
 #
 # create a new test
 #
+activity="new test 244"
 $bin/aegis -nt -lib $worklib -p foo
 if test $? -ne 0 ; then fail; fi
 cat > $workchan/test/00/t0001a.sh << 'end'
 #!/bin/sh
+no_result()
+{
+	echo WHIMPER 1>&2
+	exit 2
+}
 fail()
 {
 	echo SHUZBUTT 1>&2
@@ -221,98 +283,107 @@ pass()
 {
 	exit 0
 }
-trap "fail" 1 2 3 15
-
-./foo
-q=$?
-
-# check for signals
-if test $q -ge 128 
-then
-	fail
-fi
+trap "no_result" 1 2 3 15
 
 # should not complain
-if test $q -ne 0 
-then
-	fail
-fi
+./foo
+if test $? -ne 0; then fail; fi
 
 # it probably worked
 pass
 end
+if test $? -ne 0 ; then no_result; fi
 
 #
 # build the change
 #
+activity="build 282"
 $bin/aegis -build -nl -lib $worklib -p foo > /dev/null 2>&1
-if test $? -ne 0 ; then fail; fi
+if test $? -ne 0 ; then no_result; fi
 
 #
 # difference the change
 #
+activity="diff 289"
 $bin/aegis -diff -nl -lib $worklib -p foo > /dev/null 2>&1
-if test $? -ne 0 ; then fail; fi
+if test $? -ne 0 ; then no_result; fi
 
 #
 # test the change
 #
+activity="test 296"
 $bin/aegis -test -nl -lib $worklib -p foo > /dev/null 2>&1
-if test $? -ne 0 ; then fail; fi
+if test $? -ne 0 ; then no_result; fi
 
 #
 # finish development of the change
 #
+activity="develop end 303"
 $bin/aegis -dev_end -lib $worklib -p foo
 if test $? -ne 0 ; then fail; fi
 
 #
 # add a new reviewer
 #
+activity="new reviewer 310"
 $bin/aegis -newrev $USER -p foo -lib $worklib
-if test $? -ne 0 ; then fail; fi
+if test $? -ne 0 ; then no_result; fi
 
 #
 # pass the review
 #
+activity="review pass 317"
 $bin/aegis -review_pass -chan 1 -proj foo -lib $worklib
-if test $? -ne 0 ; then fail; fi
+if test $? -ne 0 ; then no_result; fi
 
 #
 # add an integrator
 #
+activity="new integrator 324"
 $bin/aegis -newint $USER -p foo -lib $worklib
-if test $? -ne 0 ; then fail; fi
+if test $? -ne 0 ; then no_result; fi
 
 #
 # start integrating
 #
+activity="integrate begin 331"
 $bin/aegis -intbeg 1 -p foo -lib $worklib
-if test $? -ne 0 ; then fail; fi
+if test $? -ne 0 ; then no_result; fi
 
 #
 # integrate build
 #
+activity="build 338"
 $bin/aegis -build -nl -lib $worklib -p foo > /dev/null 2>&1
-if test $? -ne 0 ; then fail; fi
+if test $? -ne 0 ; then no_result; fi
+activity="test 341"
 $bin/aegis -test -nl -lib $worklib -p foo > /dev/null 2>&1
-if test $? -ne 0 ; then fail; fi
+if test $? -ne 0 ; then no_result; fi
 
 #
 # pass the integration
 #
+activity="integrate pass 348"
 $bin/aegis -intpass -nl -lib $worklib -p foo > /dev/null 2>&1
 if test $? -ne 0 ; then fail; fi
 
+#
+# Need to sleeo for a few seconds, because the directories are removed
+# in the background.
+# 
+sleep 5
+
 #
 # see if the symbolic link in the work area has been removed
 # or wether it is still there
+# It is meant to have been removed.
 #
+activity="symlink existence 356"
 ./symlink $symlinktestfile
 if test $? -ne 0 ; then fail; fi
 
 # should be no automatic logging
-if test "`find $work -name 'aegis.log' -print`" != "" ; then fail; fi
+if test "`find $work -name 'aegis.log' -print`" != "" ; then no_result; fi
 
 #
 # the things tested in this test, worked
