@@ -1,7 +1,7 @@
 #!/bin/sh
 #
 #	aegis - project change supervisor
-#	Copyright (C) 1991, 1992, 1993, 1994, 1995, 1996, 1997, 1998 Peter Miller;
+#	Copyright (C) 1991, 1992, 1993, 1994, 1995, 1996, 1997, 1998, 1999 Peter Miller;
 #	All rights reserved.
 #
 #	This program is free software; you can redistribute it and/or modify
@@ -482,6 +482,8 @@ branch =
 	reviewer_may_integrate = true;
 	developers_may_create_changes = false;
 	default_test_exemption = false;
+	skip_unlucky = false;
+	compress_database = false;
 	history =
 	[
 		{
@@ -510,6 +512,8 @@ branch =
 		"USER",
 	];
 	minimum_change_number = 10;
+	reuse_change_numbers = true;
+	minimum_branch_number = 1;
 };
 fubar
 if test $? -ne 0 ; then no_result; fi
@@ -624,6 +628,8 @@ branch =
 	reviewer_may_integrate = true;
 	developers_may_create_changes = false;
 	default_test_exemption = false;
+	skip_unlucky = false;
+	compress_database = false;
 	change =
 	[
 		1,
@@ -649,6 +655,8 @@ branch =
 		"USER",
 	];
 	minimum_change_number = 10;
+	reuse_change_numbers = true;
+	minimum_branch_number = 1;
 };
 fubar
 if test $? -ne 0 ; then no_result; fi
@@ -706,6 +714,8 @@ branch =
 	reviewer_may_integrate = true;
 	developers_may_create_changes = false;
 	default_test_exemption = false;
+	skip_unlucky = false;
+	compress_database = false;
 	change =
 	[
 		1,
@@ -731,6 +741,8 @@ branch =
 		"USER",
 	];
 	minimum_change_number = 10;
+	reuse_change_numbers = true;
+	minimum_branch_number = 1;
 };
 fubar
 if test $? -ne 0 ; then no_result; fi
@@ -864,6 +876,8 @@ branch =
 	reviewer_may_integrate = true;
 	developers_may_create_changes = false;
 	default_test_exemption = false;
+	skip_unlucky = false;
+	compress_database = false;
 	history =
 	[
 		{
@@ -893,6 +907,8 @@ branch =
 		"USER",
 	];
 	minimum_change_number = 10;
+	reuse_change_numbers = true;
+	minimum_branch_number = 1;
 };
 fubar
 if test $? -ne 0 ; then no_result; fi
