@@ -1,7 +1,7 @@
 #!/bin/sh
 #
 #	aegis - project change supervisor
-#	Copyright (C) 1995, 1996, 1997, 1998 Peter Miller;
+#	Copyright (C) 1995, 1996, 1997, 1998, 1999 Peter Miller;
 #	All rights reserved.
 #
 #	This program is free software; you can redistribute it and/or modify
@@ -441,6 +441,8 @@ branch =
 	reviewer_may_integrate = true;
 	developers_may_create_changes = false;
 	default_test_exemption = false;
+	skip_unlucky = false;
+	compress_database = false;
 	change =
 	[
 	];
@@ -461,6 +463,8 @@ branch =
 		"USER",
 	];
 	minimum_change_number = 10;
+	reuse_change_numbers = true;
+	minimum_branch_number = 1;
 };
 fubar
 if test $? -ne 0 ; then no_result; fi
@@ -520,6 +524,8 @@ branch =
 	reviewer_may_integrate = true;
 	developers_may_create_changes = false;
 	default_test_exemption = false;
+	skip_unlucky = false;
+	compress_database = false;
 	change =
 	[
 	];
@@ -540,6 +546,8 @@ branch =
 		"USER",
 	];
 	minimum_change_number = 10;
+	reuse_change_numbers = true;
+	minimum_branch_number = 1;
 };
 fubar
 if test $? -ne 0 ; then no_result; fi
@@ -566,9 +574,9 @@ activity="check change state file 498"
 cat > ok << fubar
 brief_description = "change one of branch two";
 description = "change one of branch two";
-cause = internal_enhancement;
+cause = internal_bug;
 test_exempt = false;
-test_baseline_exempt = true;
+test_baseline_exempt = false;
 regression_test_exempt = true;
 architecture =
 [
@@ -833,6 +841,8 @@ branch =
 	reviewer_may_integrate = true;
 	developers_may_create_changes = false;
 	default_test_exemption = false;
+	skip_unlucky = false;
+	compress_database = false;
 	history =
 	[
 		{
@@ -861,6 +871,8 @@ branch =
 		"USER",
 	];
 	minimum_change_number = 10;
+	reuse_change_numbers = true;
+	minimum_branch_number = 1;
 };
 fubar
 if test $? -ne 0 ; then cat test.out; no_result; fi
