@@ -1,7 +1,7 @@
 #!/bin/sh
 #
 #	aegis - project change supervisor
-#	Copyright (C) 1997, 1998 Peter Miller;
+#	Copyright (C) 1997, 1998, 1999 Peter Miller;
 #	All rights reserved.
 #
 #	This program is free software; you can redistribute it and/or modify
@@ -381,6 +381,8 @@ branch =
 	reviewer_may_integrate = true;
 	developers_may_create_changes = false;
 	default_test_exemption = true;
+	skip_unlucky = false;
+	compress_database = false;
 	history =
 	[
 		{
@@ -415,6 +417,7 @@ branch =
 		"USER",
 	];
 	minimum_change_number = 10;
+	reuse_change_numbers = true;
 };
 fubar
 if test $? -ne 0 ; then no_result; fi
